/* Generated automatically; do not modify!     -*- buffer-read-only: t -*- */

static struct raw_instance ofpraw_ofpt_hello_instances[] = {
    { {0, NULL}, {1, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {2, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {3, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {4, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {5, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {6, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {7, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {8, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {9, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {10, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {11, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {12, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {13, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {14, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {15, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {16, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {17, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {18, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {19, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {20, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {21, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {22, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {23, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {24, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {25, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {26, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {27, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {28, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {29, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {30, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {31, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {32, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {33, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {34, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {35, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {36, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {37, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {38, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {39, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {40, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {41, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {42, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {43, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {44, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {45, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {46, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {47, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {48, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {49, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {50, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {51, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {52, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {53, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {54, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {55, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {56, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {57, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {58, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {59, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {60, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {61, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {62, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {63, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {64, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {65, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {66, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {67, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {68, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {69, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {70, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {71, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {72, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {73, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {74, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {75, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {76, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {77, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {78, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {79, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {80, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {81, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {82, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {83, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {84, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {85, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {86, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {87, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {88, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {89, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {90, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {91, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {92, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {93, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {94, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {95, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {96, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {97, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {98, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {99, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {100, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {101, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {102, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {103, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {104, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {105, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {106, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {107, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {108, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {109, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {110, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {111, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {112, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {113, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {114, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {115, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {116, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {117, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {118, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {119, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {120, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {121, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {122, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {123, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {124, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {125, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {126, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {127, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {128, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {129, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {130, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {131, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {132, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {133, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {134, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {135, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {136, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {137, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {138, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {139, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {140, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {141, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {142, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {143, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {144, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {145, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {146, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {147, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {148, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {149, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {150, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {151, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {152, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {153, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {154, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {155, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {156, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {157, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {158, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {159, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {160, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {161, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {162, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {163, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {164, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {165, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {166, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {167, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {168, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {169, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {170, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {171, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {172, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {173, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {174, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {175, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {176, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {177, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {178, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {179, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {180, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {181, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {182, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {183, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {184, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {185, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {186, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {187, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {188, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {189, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {190, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {191, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {192, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {193, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {194, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {195, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {196, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {197, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {198, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {199, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {200, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {201, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {202, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {203, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {204, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {205, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {206, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {207, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {208, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {209, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {210, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {211, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {212, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {213, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {214, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {215, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {216, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {217, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {218, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {219, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {220, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {221, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {222, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {223, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {224, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {225, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {226, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {227, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {228, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {229, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {230, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {231, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {232, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {233, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {234, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {235, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {236, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {237, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {238, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {239, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {240, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {241, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {242, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {243, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {244, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {245, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {246, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {247, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {248, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {249, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {250, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {251, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {252, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {253, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {254, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
    { {0, NULL}, {255, 0, 0, 0x0, 0}, OFPRAW_OFPT_HELLO, 0 },
};
static struct raw_instance ofpraw_ofpt_error_instances[] = {
    { {0, NULL}, {1, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {2, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {3, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {4, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {5, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {6, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {7, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {8, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {9, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {10, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {11, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {12, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {13, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {14, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {15, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {16, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {17, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {18, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {19, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {20, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {21, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {22, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {23, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {24, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {25, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {26, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {27, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {28, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {29, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {30, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {31, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {32, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {33, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {34, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {35, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {36, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {37, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {38, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {39, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {40, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {41, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {42, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {43, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {44, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {45, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {46, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {47, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {48, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {49, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {50, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {51, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {52, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {53, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {54, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {55, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {56, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {57, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {58, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {59, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {60, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {61, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {62, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {63, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {64, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {65, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {66, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {67, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {68, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {69, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {70, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {71, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {72, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {73, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {74, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {75, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {76, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {77, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {78, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {79, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {80, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {81, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {82, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {83, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {84, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {85, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {86, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {87, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {88, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {89, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {90, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {91, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {92, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {93, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {94, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {95, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {96, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {97, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {98, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {99, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {100, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {101, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {102, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {103, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {104, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {105, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {106, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {107, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {108, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {109, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {110, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {111, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {112, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {113, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {114, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {115, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {116, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {117, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {118, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {119, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {120, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {121, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {122, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {123, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {124, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {125, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {126, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {127, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {128, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {129, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {130, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {131, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {132, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {133, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {134, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {135, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {136, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {137, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {138, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {139, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {140, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {141, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {142, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {143, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {144, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {145, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {146, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {147, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {148, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {149, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {150, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {151, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {152, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {153, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {154, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {155, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {156, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {157, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {158, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {159, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {160, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {161, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {162, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {163, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {164, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {165, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {166, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {167, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {168, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {169, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {170, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {171, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {172, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {173, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {174, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {175, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {176, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {177, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {178, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {179, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {180, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {181, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {182, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {183, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {184, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {185, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {186, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {187, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {188, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {189, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {190, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {191, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {192, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {193, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {194, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {195, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {196, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {197, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {198, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {199, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {200, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {201, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {202, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {203, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {204, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {205, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {206, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {207, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {208, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {209, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {210, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {211, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {212, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {213, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {214, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {215, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {216, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {217, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {218, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {219, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {220, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {221, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {222, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {223, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {224, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {225, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {226, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {227, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {228, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {229, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {230, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {231, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {232, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {233, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {234, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {235, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {236, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {237, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {238, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {239, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {240, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {241, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {242, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {243, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {244, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {245, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {246, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {247, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {248, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {249, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {250, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {251, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {252, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {253, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {254, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
    { {0, NULL}, {255, 1, 0, 0x0, 0}, OFPRAW_OFPT_ERROR, 0 },
};
static struct raw_instance ofpraw_ofpt_echo_request_instances[] = {
    { {0, NULL}, {1, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {2, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {3, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {4, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {5, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {6, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {7, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {8, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {9, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {10, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {11, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {12, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {13, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {14, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {15, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {16, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {17, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {18, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {19, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {20, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {21, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {22, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {23, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {24, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {25, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {26, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {27, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {28, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {29, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {30, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {31, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {32, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {33, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {34, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {35, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {36, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {37, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {38, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {39, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {40, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {41, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {42, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {43, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {44, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {45, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {46, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {47, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {48, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {49, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {50, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {51, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {52, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {53, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {54, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {55, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {56, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {57, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {58, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {59, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {60, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {61, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {62, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {63, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {64, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {65, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {66, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {67, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {68, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {69, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {70, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {71, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {72, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {73, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {74, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {75, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {76, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {77, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {78, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {79, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {80, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {81, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {82, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {83, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {84, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {85, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {86, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {87, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {88, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {89, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {90, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {91, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {92, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {93, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {94, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {95, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {96, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {97, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {98, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {99, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {100, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {101, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {102, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {103, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {104, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {105, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {106, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {107, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {108, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {109, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {110, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {111, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {112, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {113, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {114, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {115, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {116, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {117, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {118, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {119, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {120, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {121, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {122, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {123, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {124, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {125, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {126, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {127, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {128, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {129, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {130, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {131, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {132, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {133, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {134, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {135, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {136, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {137, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {138, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {139, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {140, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {141, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {142, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {143, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {144, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {145, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {146, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {147, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {148, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {149, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {150, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {151, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {152, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {153, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {154, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {155, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {156, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {157, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {158, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {159, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {160, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {161, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {162, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {163, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {164, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {165, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {166, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {167, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {168, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {169, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {170, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {171, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {172, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {173, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {174, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {175, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {176, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {177, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {178, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {179, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {180, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {181, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {182, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {183, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {184, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {185, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {186, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {187, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {188, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {189, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {190, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {191, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {192, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {193, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {194, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {195, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {196, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {197, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {198, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {199, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {200, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {201, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {202, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {203, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {204, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {205, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {206, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {207, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {208, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {209, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {210, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {211, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {212, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {213, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {214, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {215, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {216, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {217, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {218, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {219, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {220, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {221, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {222, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {223, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {224, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {225, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {226, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {227, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {228, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {229, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {230, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {231, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {232, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {233, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {234, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {235, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {236, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {237, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {238, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {239, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {240, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {241, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {242, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {243, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {244, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {245, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {246, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {247, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {248, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {249, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {250, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {251, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {252, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {253, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {254, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
    { {0, NULL}, {255, 2, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt_echo_reply_instances[] = {
    { {0, NULL}, {1, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {2, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {3, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {4, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {5, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {6, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {7, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {8, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {9, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {10, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {11, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {12, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {13, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {14, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {15, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {16, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {17, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {18, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {19, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {20, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {21, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {22, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {23, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {24, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {25, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {26, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {27, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {28, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {29, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {30, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {31, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {32, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {33, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {34, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {35, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {36, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {37, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {38, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {39, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {40, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {41, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {42, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {43, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {44, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {45, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {46, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {47, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {48, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {49, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {50, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {51, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {52, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {53, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {54, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {55, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {56, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {57, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {58, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {59, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {60, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {61, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {62, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {63, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {64, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {65, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {66, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {67, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {68, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {69, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {70, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {71, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {72, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {73, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {74, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {75, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {76, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {77, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {78, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {79, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {80, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {81, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {82, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {83, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {84, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {85, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {86, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {87, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {88, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {89, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {90, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {91, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {92, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {93, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {94, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {95, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {96, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {97, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {98, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {99, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {100, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {101, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {102, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {103, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {104, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {105, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {106, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {107, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {108, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {109, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {110, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {111, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {112, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {113, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {114, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {115, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {116, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {117, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {118, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {119, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {120, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {121, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {122, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {123, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {124, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {125, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {126, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {127, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {128, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {129, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {130, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {131, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {132, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {133, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {134, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {135, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {136, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {137, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {138, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {139, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {140, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {141, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {142, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {143, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {144, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {145, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {146, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {147, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {148, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {149, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {150, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {151, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {152, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {153, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {154, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {155, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {156, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {157, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {158, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {159, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {160, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {161, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {162, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {163, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {164, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {165, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {166, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {167, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {168, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {169, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {170, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {171, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {172, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {173, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {174, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {175, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {176, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {177, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {178, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {179, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {180, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {181, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {182, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {183, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {184, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {185, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {186, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {187, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {188, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {189, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {190, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {191, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {192, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {193, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {194, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {195, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {196, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {197, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {198, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {199, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {200, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {201, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {202, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {203, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {204, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {205, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {206, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {207, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {208, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {209, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {210, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {211, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {212, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {213, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {214, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {215, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {216, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {217, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {218, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {219, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {220, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {221, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {222, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {223, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {224, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {225, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {226, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {227, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {228, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {229, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {230, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {231, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {232, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {233, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {234, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {235, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {236, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {237, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {238, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {239, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {240, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {241, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {242, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {243, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {244, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {245, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {246, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {247, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {248, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {249, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {250, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {251, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {252, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {253, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {254, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
    { {0, NULL}, {255, 3, 0, 0x0, 0}, OFPRAW_OFPT_ECHO_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt_features_request_instances[] = {
    { {0, NULL}, {1, 5, 0, 0x0, 0}, OFPRAW_OFPT_FEATURES_REQUEST, 0 },
    { {0, NULL}, {2, 5, 0, 0x0, 0}, OFPRAW_OFPT_FEATURES_REQUEST, 0 },
    { {0, NULL}, {3, 5, 0, 0x0, 0}, OFPRAW_OFPT_FEATURES_REQUEST, 0 },
    { {0, NULL}, {4, 5, 0, 0x0, 0}, OFPRAW_OFPT_FEATURES_REQUEST, 0 },
    { {0, NULL}, {5, 5, 0, 0x0, 0}, OFPRAW_OFPT_FEATURES_REQUEST, 0 },
    { {0, NULL}, {6, 5, 0, 0x0, 0}, OFPRAW_OFPT_FEATURES_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt10_features_reply_instances[] = {
    { {0, NULL}, {1, 6, 0, 0x0, 0}, OFPRAW_OFPT10_FEATURES_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt11_features_reply_instances[] = {
    { {0, NULL}, {2, 6, 0, 0x0, 0}, OFPRAW_OFPT11_FEATURES_REPLY, 0 },
    { {0, NULL}, {3, 6, 0, 0x0, 0}, OFPRAW_OFPT11_FEATURES_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt13_features_reply_instances[] = {
    { {0, NULL}, {4, 6, 0, 0x0, 0}, OFPRAW_OFPT13_FEATURES_REPLY, 0 },
    { {0, NULL}, {5, 6, 0, 0x0, 0}, OFPRAW_OFPT13_FEATURES_REPLY, 0 },
    { {0, NULL}, {6, 6, 0, 0x0, 0}, OFPRAW_OFPT13_FEATURES_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt_get_config_request_instances[] = {
    { {0, NULL}, {1, 7, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REQUEST, 0 },
    { {0, NULL}, {2, 7, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REQUEST, 0 },
    { {0, NULL}, {3, 7, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REQUEST, 0 },
    { {0, NULL}, {4, 7, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REQUEST, 0 },
    { {0, NULL}, {5, 7, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REQUEST, 0 },
    { {0, NULL}, {6, 7, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt_get_config_reply_instances[] = {
    { {0, NULL}, {1, 8, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REPLY, 0 },
    { {0, NULL}, {2, 8, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REPLY, 0 },
    { {0, NULL}, {3, 8, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REPLY, 0 },
    { {0, NULL}, {4, 8, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REPLY, 0 },
    { {0, NULL}, {5, 8, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REPLY, 0 },
    { {0, NULL}, {6, 8, 0, 0x0, 0}, OFPRAW_OFPT_GET_CONFIG_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt_set_config_instances[] = {
    { {0, NULL}, {1, 9, 0, 0x0, 0}, OFPRAW_OFPT_SET_CONFIG, 0 },
    { {0, NULL}, {2, 9, 0, 0x0, 0}, OFPRAW_OFPT_SET_CONFIG, 0 },
    { {0, NULL}, {3, 9, 0, 0x0, 0}, OFPRAW_OFPT_SET_CONFIG, 0 },
    { {0, NULL}, {4, 9, 0, 0x0, 0}, OFPRAW_OFPT_SET_CONFIG, 0 },
    { {0, NULL}, {5, 9, 0, 0x0, 0}, OFPRAW_OFPT_SET_CONFIG, 0 },
    { {0, NULL}, {6, 9, 0, 0x0, 0}, OFPRAW_OFPT_SET_CONFIG, 0 },
};
static struct raw_instance ofpraw_ofpt10_packet_in_instances[] = {
    { {0, NULL}, {1, 10, 0, 0x0, 0}, OFPRAW_OFPT10_PACKET_IN, 0 },
};
static struct raw_instance ofpraw_ofpt11_packet_in_instances[] = {
    { {0, NULL}, {2, 10, 0, 0x0, 0}, OFPRAW_OFPT11_PACKET_IN, 0 },
};
static struct raw_instance ofpraw_ofpt12_packet_in_instances[] = {
    { {0, NULL}, {3, 10, 0, 0x0, 0}, OFPRAW_OFPT12_PACKET_IN, 0 },
};
static struct raw_instance ofpraw_ofpt13_packet_in_instances[] = {
    { {0, NULL}, {4, 10, 0, 0x0, 0}, OFPRAW_OFPT13_PACKET_IN, 0 },
    { {0, NULL}, {5, 10, 0, 0x0, 0}, OFPRAW_OFPT13_PACKET_IN, 0 },
    { {0, NULL}, {6, 10, 0, 0x0, 0}, OFPRAW_OFPT13_PACKET_IN, 0 },
};
static struct raw_instance ofpraw_nxt_packet_in_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 17}, OFPRAW_NXT_PACKET_IN, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 17}, OFPRAW_NXT_PACKET_IN, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 17}, OFPRAW_NXT_PACKET_IN, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 17}, OFPRAW_NXT_PACKET_IN, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 17}, OFPRAW_NXT_PACKET_IN, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 17}, OFPRAW_NXT_PACKET_IN, 0 },
};
static struct raw_instance ofpraw_nxt_packet_in2_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 30}, OFPRAW_NXT_PACKET_IN2, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 30}, OFPRAW_NXT_PACKET_IN2, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 30}, OFPRAW_NXT_PACKET_IN2, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 30}, OFPRAW_NXT_PACKET_IN2, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 30}, OFPRAW_NXT_PACKET_IN2, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 30}, OFPRAW_NXT_PACKET_IN2, 0 },
};
static struct raw_instance ofpraw_ofpt10_flow_removed_instances[] = {
    { {0, NULL}, {1, 11, 0, 0x0, 0}, OFPRAW_OFPT10_FLOW_REMOVED, 0 },
};
static struct raw_instance ofpraw_ofpt11_flow_removed_instances[] = {
    { {0, NULL}, {2, 11, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_REMOVED, 0 },
    { {0, NULL}, {3, 11, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_REMOVED, 0 },
    { {0, NULL}, {4, 11, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_REMOVED, 0 },
    { {0, NULL}, {5, 11, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_REMOVED, 0 },
};
static struct raw_instance ofpraw_ofpt15_flow_removed_instances[] = {
    { {0, NULL}, {6, 11, 0, 0x0, 0}, OFPRAW_OFPT15_FLOW_REMOVED, 0 },
};
static struct raw_instance ofpraw_nxt_flow_removed_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 14}, OFPRAW_NXT_FLOW_REMOVED, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 14}, OFPRAW_NXT_FLOW_REMOVED, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 14}, OFPRAW_NXT_FLOW_REMOVED, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 14}, OFPRAW_NXT_FLOW_REMOVED, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 14}, OFPRAW_NXT_FLOW_REMOVED, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 14}, OFPRAW_NXT_FLOW_REMOVED, 0 },
};
static struct raw_instance ofpraw_ofpt10_port_status_instances[] = {
    { {0, NULL}, {1, 12, 0, 0x0, 0}, OFPRAW_OFPT10_PORT_STATUS, 0 },
};
static struct raw_instance ofpraw_ofpt11_port_status_instances[] = {
    { {0, NULL}, {2, 12, 0, 0x0, 0}, OFPRAW_OFPT11_PORT_STATUS, 0 },
    { {0, NULL}, {3, 12, 0, 0x0, 0}, OFPRAW_OFPT11_PORT_STATUS, 0 },
    { {0, NULL}, {4, 12, 0, 0x0, 0}, OFPRAW_OFPT11_PORT_STATUS, 0 },
};
static struct raw_instance ofpraw_ofpt14_port_status_instances[] = {
    { {0, NULL}, {5, 12, 0, 0x0, 0}, OFPRAW_OFPT14_PORT_STATUS, 0 },
    { {0, NULL}, {6, 12, 0, 0x0, 0}, OFPRAW_OFPT14_PORT_STATUS, 0 },
};
static struct raw_instance ofpraw_ofpt10_packet_out_instances[] = {
    { {0, NULL}, {1, 13, 0, 0x0, 0}, OFPRAW_OFPT10_PACKET_OUT, 0 },
};
static struct raw_instance ofpraw_ofpt11_packet_out_instances[] = {
    { {0, NULL}, {2, 13, 0, 0x0, 0}, OFPRAW_OFPT11_PACKET_OUT, 0 },
    { {0, NULL}, {3, 13, 0, 0x0, 0}, OFPRAW_OFPT11_PACKET_OUT, 0 },
    { {0, NULL}, {4, 13, 0, 0x0, 0}, OFPRAW_OFPT11_PACKET_OUT, 0 },
    { {0, NULL}, {5, 13, 0, 0x0, 0}, OFPRAW_OFPT11_PACKET_OUT, 0 },
};
static struct raw_instance ofpraw_ofpt15_packet_out_instances[] = {
    { {0, NULL}, {6, 13, 0, 0x0, 0}, OFPRAW_OFPT15_PACKET_OUT, 0 },
};
static struct raw_instance ofpraw_ofpt10_flow_mod_instances[] = {
    { {0, NULL}, {1, 14, 0, 0x0, 0}, OFPRAW_OFPT10_FLOW_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt11_flow_mod_instances[] = {
    { {0, NULL}, {2, 14, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_MOD, 0 },
    { {0, NULL}, {3, 14, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_MOD, 0 },
    { {0, NULL}, {4, 14, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_MOD, 0 },
    { {0, NULL}, {5, 14, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_MOD, 0 },
    { {0, NULL}, {6, 14, 0, 0x0, 0}, OFPRAW_OFPT11_FLOW_MOD, 0 },
};
static struct raw_instance ofpraw_nxt_flow_mod_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 13}, OFPRAW_NXT_FLOW_MOD, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 13}, OFPRAW_NXT_FLOW_MOD, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 13}, OFPRAW_NXT_FLOW_MOD, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 13}, OFPRAW_NXT_FLOW_MOD, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 13}, OFPRAW_NXT_FLOW_MOD, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 13}, OFPRAW_NXT_FLOW_MOD, 0 },
};
static struct raw_instance ofpraw_nxt_group_mod_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 31}, OFPRAW_NXT_GROUP_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt11_group_mod_instances[] = {
    { {0, NULL}, {2, 15, 0, 0x0, 0}, OFPRAW_OFPT11_GROUP_MOD, 0 },
    { {0, NULL}, {3, 15, 0, 0x0, 0}, OFPRAW_OFPT11_GROUP_MOD, 0 },
    { {0, NULL}, {4, 15, 0, 0x0, 0}, OFPRAW_OFPT11_GROUP_MOD, 0 },
    { {0, NULL}, {5, 15, 0, 0x0, 0}, OFPRAW_OFPT11_GROUP_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt15_group_mod_instances[] = {
    { {0, NULL}, {6, 15, 0, 0x0, 0}, OFPRAW_OFPT15_GROUP_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt10_port_mod_instances[] = {
    { {0, NULL}, {1, 15, 0, 0x0, 0}, OFPRAW_OFPT10_PORT_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt11_port_mod_instances[] = {
    { {0, NULL}, {2, 16, 0, 0x0, 0}, OFPRAW_OFPT11_PORT_MOD, 0 },
    { {0, NULL}, {3, 16, 0, 0x0, 0}, OFPRAW_OFPT11_PORT_MOD, 0 },
    { {0, NULL}, {4, 16, 0, 0x0, 0}, OFPRAW_OFPT11_PORT_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt14_port_mod_instances[] = {
    { {0, NULL}, {5, 16, 0, 0x0, 0}, OFPRAW_OFPT14_PORT_MOD, 0 },
    { {0, NULL}, {6, 16, 0, 0x0, 0}, OFPRAW_OFPT14_PORT_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt11_table_mod_instances[] = {
    { {0, NULL}, {2, 17, 0, 0x0, 0}, OFPRAW_OFPT11_TABLE_MOD, 0 },
    { {0, NULL}, {3, 17, 0, 0x0, 0}, OFPRAW_OFPT11_TABLE_MOD, 0 },
    { {0, NULL}, {4, 17, 0, 0x0, 0}, OFPRAW_OFPT11_TABLE_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt14_table_mod_instances[] = {
    { {0, NULL}, {5, 17, 0, 0x0, 0}, OFPRAW_OFPT14_TABLE_MOD, 0 },
    { {0, NULL}, {6, 17, 0, 0x0, 0}, OFPRAW_OFPT14_TABLE_MOD, 0 },
};
static struct raw_instance ofpraw_ofpt10_barrier_request_instances[] = {
    { {0, NULL}, {1, 18, 0, 0x0, 0}, OFPRAW_OFPT10_BARRIER_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt11_barrier_request_instances[] = {
    { {0, NULL}, {2, 20, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REQUEST, 0 },
    { {0, NULL}, {3, 20, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REQUEST, 0 },
    { {0, NULL}, {4, 20, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REQUEST, 0 },
    { {0, NULL}, {5, 20, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REQUEST, 0 },
    { {0, NULL}, {6, 20, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt10_barrier_reply_instances[] = {
    { {0, NULL}, {1, 19, 0, 0x0, 0}, OFPRAW_OFPT10_BARRIER_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt11_barrier_reply_instances[] = {
    { {0, NULL}, {2, 21, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REPLY, 0 },
    { {0, NULL}, {3, 21, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REPLY, 0 },
    { {0, NULL}, {4, 21, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REPLY, 0 },
    { {0, NULL}, {5, 21, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REPLY, 0 },
    { {0, NULL}, {6, 21, 0, 0x0, 0}, OFPRAW_OFPT11_BARRIER_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt10_queue_get_config_request_instances[] = {
    { {0, NULL}, {1, 20, 0, 0x0, 0}, OFPRAW_OFPT10_QUEUE_GET_CONFIG_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt11_queue_get_config_request_instances[] = {
    { {0, NULL}, {2, 22, 0, 0x0, 0}, OFPRAW_OFPT11_QUEUE_GET_CONFIG_REQUEST, 0 },
    { {0, NULL}, {3, 22, 0, 0x0, 0}, OFPRAW_OFPT11_QUEUE_GET_CONFIG_REQUEST, 0 },
    { {0, NULL}, {4, 22, 0, 0x0, 0}, OFPRAW_OFPT11_QUEUE_GET_CONFIG_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt10_queue_get_config_reply_instances[] = {
    { {0, NULL}, {1, 21, 0, 0x0, 0}, OFPRAW_OFPT10_QUEUE_GET_CONFIG_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt11_queue_get_config_reply_instances[] = {
    { {0, NULL}, {2, 23, 0, 0x0, 0}, OFPRAW_OFPT11_QUEUE_GET_CONFIG_REPLY, 0 },
    { {0, NULL}, {3, 23, 0, 0x0, 0}, OFPRAW_OFPT11_QUEUE_GET_CONFIG_REPLY, 0 },
    { {0, NULL}, {4, 23, 0, 0x0, 0}, OFPRAW_OFPT11_QUEUE_GET_CONFIG_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt12_role_request_instances[] = {
    { {0, NULL}, {3, 24, 0, 0x0, 0}, OFPRAW_OFPT12_ROLE_REQUEST, 0 },
    { {0, NULL}, {4, 24, 0, 0x0, 0}, OFPRAW_OFPT12_ROLE_REQUEST, 0 },
    { {0, NULL}, {5, 24, 0, 0x0, 0}, OFPRAW_OFPT12_ROLE_REQUEST, 0 },
    { {0, NULL}, {6, 24, 0, 0x0, 0}, OFPRAW_OFPT12_ROLE_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxt_role_request_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 10}, OFPRAW_NXT_ROLE_REQUEST, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 10}, OFPRAW_NXT_ROLE_REQUEST, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 10}, OFPRAW_NXT_ROLE_REQUEST, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 10}, OFPRAW_NXT_ROLE_REQUEST, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 10}, OFPRAW_NXT_ROLE_REQUEST, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 10}, OFPRAW_NXT_ROLE_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt12_role_reply_instances[] = {
    { {0, NULL}, {3, 25, 0, 0x0, 0}, OFPRAW_OFPT12_ROLE_REPLY, 0 },
    { {0, NULL}, {4, 25, 0, 0x0, 0}, OFPRAW_OFPT12_ROLE_REPLY, 0 },
    { {0, NULL}, {5, 25, 0, 0x0, 0}, OFPRAW_OFPT12_ROLE_REPLY, 0 },
    { {0, NULL}, {6, 25, 0, 0x0, 0}, OFPRAW_OFPT12_ROLE_REPLY, 0 },
};
static struct raw_instance ofpraw_nxt_role_reply_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 11}, OFPRAW_NXT_ROLE_REPLY, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 11}, OFPRAW_NXT_ROLE_REPLY, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 11}, OFPRAW_NXT_ROLE_REPLY, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 11}, OFPRAW_NXT_ROLE_REPLY, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 11}, OFPRAW_NXT_ROLE_REPLY, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 11}, OFPRAW_NXT_ROLE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt13_get_async_request_instances[] = {
    { {0, NULL}, {4, 26, 0, 0x0, 0}, OFPRAW_OFPT13_GET_ASYNC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt14_get_async_request_instances[] = {
    { {0, NULL}, {5, 26, 0, 0x0, 0}, OFPRAW_OFPT14_GET_ASYNC_REQUEST, 0 },
    { {0, NULL}, {6, 26, 0, 0x0, 0}, OFPRAW_OFPT14_GET_ASYNC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpt13_get_async_reply_instances[] = {
    { {0, NULL}, {4, 27, 0, 0x0, 0}, OFPRAW_OFPT13_GET_ASYNC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt14_get_async_reply_instances[] = {
    { {0, NULL}, {5, 27, 0, 0x0, 0}, OFPRAW_OFPT14_GET_ASYNC_REPLY, 0 },
    { {0, NULL}, {6, 27, 0, 0x0, 0}, OFPRAW_OFPT14_GET_ASYNC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpt13_set_async_instances[] = {
    { {0, NULL}, {4, 28, 0, 0x0, 0}, OFPRAW_OFPT13_SET_ASYNC, 0 },
};
static struct raw_instance ofpraw_nxt_set_async_config_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 19}, OFPRAW_NXT_SET_ASYNC_CONFIG, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 19}, OFPRAW_NXT_SET_ASYNC_CONFIG, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 19}, OFPRAW_NXT_SET_ASYNC_CONFIG, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 19}, OFPRAW_NXT_SET_ASYNC_CONFIG, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 19}, OFPRAW_NXT_SET_ASYNC_CONFIG, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 19}, OFPRAW_NXT_SET_ASYNC_CONFIG, 0 },
};
static struct raw_instance ofpraw_nxt_set_async_config2_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 27}, OFPRAW_NXT_SET_ASYNC_CONFIG2, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 27}, OFPRAW_NXT_SET_ASYNC_CONFIG2, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 27}, OFPRAW_NXT_SET_ASYNC_CONFIG2, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 27}, OFPRAW_NXT_SET_ASYNC_CONFIG2, 0 },
};
static struct raw_instance ofpraw_ofpt14_set_async_instances[] = {
    { {0, NULL}, {5, 28, 0, 0x0, 0}, OFPRAW_OFPT14_SET_ASYNC, 0 },
    { {0, NULL}, {6, 28, 0, 0x0, 0}, OFPRAW_OFPT14_SET_ASYNC, 0 },
};
static struct raw_instance ofpraw_ofpt13_meter_mod_instances[] = {
    { {0, NULL}, {4, 29, 0, 0x0, 0}, OFPRAW_OFPT13_METER_MOD, 0 },
    { {0, NULL}, {5, 29, 0, 0x0, 0}, OFPRAW_OFPT13_METER_MOD, 0 },
    { {0, NULL}, {6, 29, 0, 0x0, 0}, OFPRAW_OFPT13_METER_MOD, 0 },
};
static struct raw_instance ofpraw_onft13_role_status_instances[] = {
    { {0, NULL}, {4, 4, 0, 0x4f4e4600, 1911}, OFPRAW_ONFT13_ROLE_STATUS, 0 },
};
static struct raw_instance ofpraw_ofpt14_role_status_instances[] = {
    { {0, NULL}, {5, 30, 0, 0x0, 0}, OFPRAW_OFPT14_ROLE_STATUS, 0 },
    { {0, NULL}, {6, 30, 0, 0x0, 0}, OFPRAW_OFPT14_ROLE_STATUS, 0 },
};
static struct raw_instance ofpraw_ofpt14_table_status_instances[] = {
    { {0, NULL}, {5, 31, 0, 0x0, 0}, OFPRAW_OFPT14_TABLE_STATUS, 0 },
    { {0, NULL}, {6, 31, 0, 0x0, 0}, OFPRAW_OFPT14_TABLE_STATUS, 0 },
};
static struct raw_instance ofpraw_nxt_requestforward_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 132}, OFPRAW_NXT_REQUESTFORWARD, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 132}, OFPRAW_NXT_REQUESTFORWARD, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 132}, OFPRAW_NXT_REQUESTFORWARD, 0 },
};
static struct raw_instance ofpraw_onft13_requestforward_instances[] = {
    { {0, NULL}, {4, 4, 0, 0x4f4e4600, 2350}, OFPRAW_ONFT13_REQUESTFORWARD, 0 },
};
static struct raw_instance ofpraw_ofpt14_requestforward_instances[] = {
    { {0, NULL}, {5, 32, 0, 0x0, 0}, OFPRAW_OFPT14_REQUESTFORWARD, 0 },
    { {0, NULL}, {6, 32, 0, 0x0, 0}, OFPRAW_OFPT14_REQUESTFORWARD, 0 },
};
static struct raw_instance ofpraw_ofpt14_bundle_control_instances[] = {
    { {0, NULL}, {5, 33, 0, 0x0, 0}, OFPRAW_OFPT14_BUNDLE_CONTROL, 0 },
    { {0, NULL}, {6, 33, 0, 0x0, 0}, OFPRAW_OFPT14_BUNDLE_CONTROL, 0 },
};
static struct raw_instance ofpraw_onft13_bundle_control_instances[] = {
    { {0, NULL}, {4, 4, 0, 0x4f4e4600, 2300}, OFPRAW_ONFT13_BUNDLE_CONTROL, 0 },
};
static struct raw_instance ofpraw_ofpt14_bundle_add_message_instances[] = {
    { {0, NULL}, {5, 34, 0, 0x0, 0}, OFPRAW_OFPT14_BUNDLE_ADD_MESSAGE, 0 },
    { {0, NULL}, {6, 34, 0, 0x0, 0}, OFPRAW_OFPT14_BUNDLE_ADD_MESSAGE, 0 },
};
static struct raw_instance ofpraw_onft13_bundle_add_message_instances[] = {
    { {0, NULL}, {4, 4, 0, 0x4f4e4600, 2301}, OFPRAW_ONFT13_BUNDLE_ADD_MESSAGE, 0 },
};
static struct raw_instance ofpraw_ofpst_desc_request_instances[] = {
    { {0, NULL}, {1, 16, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REQUEST, 0 },
    { {0, NULL}, {2, 18, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REQUEST, 0 },
    { {0, NULL}, {3, 18, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REQUEST, 0 },
    { {0, NULL}, {4, 18, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REQUEST, 0 },
    { {0, NULL}, {5, 18, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REQUEST, 0 },
    { {0, NULL}, {6, 18, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst_desc_reply_instances[] = {
    { {0, NULL}, {1, 17, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REPLY, 0 },
    { {0, NULL}, {2, 19, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REPLY, 0 },
    { {0, NULL}, {3, 19, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REPLY, 0 },
    { {0, NULL}, {4, 19, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REPLY, 0 },
    { {0, NULL}, {5, 19, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REPLY, 0 },
    { {0, NULL}, {6, 19, 0, 0x0, 0}, OFPRAW_OFPST_DESC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst10_flow_request_instances[] = {
    { {0, NULL}, {1, 16, 1, 0x0, 0}, OFPRAW_OFPST10_FLOW_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst11_flow_request_instances[] = {
    { {0, NULL}, {2, 18, 1, 0x0, 0}, OFPRAW_OFPST11_FLOW_REQUEST, 0 },
    { {0, NULL}, {3, 18, 1, 0x0, 0}, OFPRAW_OFPST11_FLOW_REQUEST, 0 },
    { {0, NULL}, {4, 18, 1, 0x0, 0}, OFPRAW_OFPST11_FLOW_REQUEST, 0 },
    { {0, NULL}, {5, 18, 1, 0x0, 0}, OFPRAW_OFPST11_FLOW_REQUEST, 0 },
    { {0, NULL}, {6, 18, 1, 0x0, 0}, OFPRAW_OFPST11_FLOW_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxst_flow_request_instances[] = {
    { {0, NULL}, {1, 16, 65535, 0x2320, 0}, OFPRAW_NXST_FLOW_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst10_flow_reply_instances[] = {
    { {0, NULL}, {1, 17, 1, 0x0, 0}, OFPRAW_OFPST10_FLOW_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst11_flow_reply_instances[] = {
    { {0, NULL}, {2, 19, 1, 0x0, 0}, OFPRAW_OFPST11_FLOW_REPLY, 0 },
    { {0, NULL}, {3, 19, 1, 0x0, 0}, OFPRAW_OFPST11_FLOW_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_flow_reply_instances[] = {
    { {0, NULL}, {4, 19, 1, 0x0, 0}, OFPRAW_OFPST13_FLOW_REPLY, 0 },
    { {0, NULL}, {5, 19, 1, 0x0, 0}, OFPRAW_OFPST13_FLOW_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst15_flow_reply_instances[] = {
    { {0, NULL}, {6, 19, 1, 0x0, 0}, OFPRAW_OFPST15_FLOW_REPLY, 0 },
};
static struct raw_instance ofpraw_nxst_flow_reply_instances[] = {
    { {0, NULL}, {1, 17, 65535, 0x2320, 0}, OFPRAW_NXST_FLOW_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst10_aggregate_request_instances[] = {
    { {0, NULL}, {1, 16, 2, 0x0, 0}, OFPRAW_OFPST10_AGGREGATE_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst11_aggregate_request_instances[] = {
    { {0, NULL}, {2, 18, 2, 0x0, 0}, OFPRAW_OFPST11_AGGREGATE_REQUEST, 0 },
    { {0, NULL}, {3, 18, 2, 0x0, 0}, OFPRAW_OFPST11_AGGREGATE_REQUEST, 0 },
    { {0, NULL}, {4, 18, 2, 0x0, 0}, OFPRAW_OFPST11_AGGREGATE_REQUEST, 0 },
    { {0, NULL}, {5, 18, 2, 0x0, 0}, OFPRAW_OFPST11_AGGREGATE_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst15_aggregate_request_instances[] = {
    { {0, NULL}, {6, 18, 2, 0x0, 0}, OFPRAW_OFPST15_AGGREGATE_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxst_aggregate_request_instances[] = {
    { {0, NULL}, {1, 16, 65535, 0x2320, 1}, OFPRAW_NXST_AGGREGATE_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst_aggregate_reply_instances[] = {
    { {0, NULL}, {1, 17, 2, 0x0, 0}, OFPRAW_OFPST_AGGREGATE_REPLY, 0 },
    { {0, NULL}, {2, 19, 2, 0x0, 0}, OFPRAW_OFPST_AGGREGATE_REPLY, 0 },
    { {0, NULL}, {3, 19, 2, 0x0, 0}, OFPRAW_OFPST_AGGREGATE_REPLY, 0 },
    { {0, NULL}, {4, 19, 2, 0x0, 0}, OFPRAW_OFPST_AGGREGATE_REPLY, 0 },
    { {0, NULL}, {5, 19, 2, 0x0, 0}, OFPRAW_OFPST_AGGREGATE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst15_aggregate_reply_instances[] = {
    { {0, NULL}, {6, 19, 2, 0x0, 0}, OFPRAW_OFPST15_AGGREGATE_REPLY, 0 },
};
static struct raw_instance ofpraw_nxst_aggregate_reply_instances[] = {
    { {0, NULL}, {1, 17, 65535, 0x2320, 1}, OFPRAW_NXST_AGGREGATE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst_table_request_instances[] = {
    { {0, NULL}, {1, 16, 3, 0x0, 0}, OFPRAW_OFPST_TABLE_REQUEST, 0 },
    { {0, NULL}, {2, 18, 3, 0x0, 0}, OFPRAW_OFPST_TABLE_REQUEST, 0 },
    { {0, NULL}, {3, 18, 3, 0x0, 0}, OFPRAW_OFPST_TABLE_REQUEST, 0 },
    { {0, NULL}, {4, 18, 3, 0x0, 0}, OFPRAW_OFPST_TABLE_REQUEST, 0 },
    { {0, NULL}, {5, 18, 3, 0x0, 0}, OFPRAW_OFPST_TABLE_REQUEST, 0 },
    { {0, NULL}, {6, 18, 3, 0x0, 0}, OFPRAW_OFPST_TABLE_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst10_table_reply_instances[] = {
    { {0, NULL}, {1, 17, 3, 0x0, 0}, OFPRAW_OFPST10_TABLE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst11_table_reply_instances[] = {
    { {0, NULL}, {2, 19, 3, 0x0, 0}, OFPRAW_OFPST11_TABLE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst12_table_reply_instances[] = {
    { {0, NULL}, {3, 19, 3, 0x0, 0}, OFPRAW_OFPST12_TABLE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_table_reply_instances[] = {
    { {0, NULL}, {4, 19, 3, 0x0, 0}, OFPRAW_OFPST13_TABLE_REPLY, 0 },
    { {0, NULL}, {5, 19, 3, 0x0, 0}, OFPRAW_OFPST13_TABLE_REPLY, 0 },
    { {0, NULL}, {6, 19, 3, 0x0, 0}, OFPRAW_OFPST13_TABLE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst10_port_request_instances[] = {
    { {0, NULL}, {1, 16, 4, 0x0, 0}, OFPRAW_OFPST10_PORT_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst11_port_request_instances[] = {
    { {0, NULL}, {2, 18, 4, 0x0, 0}, OFPRAW_OFPST11_PORT_REQUEST, 0 },
    { {0, NULL}, {3, 18, 4, 0x0, 0}, OFPRAW_OFPST11_PORT_REQUEST, 0 },
    { {0, NULL}, {4, 18, 4, 0x0, 0}, OFPRAW_OFPST11_PORT_REQUEST, 0 },
    { {0, NULL}, {5, 18, 4, 0x0, 0}, OFPRAW_OFPST11_PORT_REQUEST, 0 },
    { {0, NULL}, {6, 18, 4, 0x0, 0}, OFPRAW_OFPST11_PORT_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst10_port_reply_instances[] = {
    { {0, NULL}, {1, 17, 4, 0x0, 0}, OFPRAW_OFPST10_PORT_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst11_port_reply_instances[] = {
    { {0, NULL}, {2, 19, 4, 0x0, 0}, OFPRAW_OFPST11_PORT_REPLY, 0 },
    { {0, NULL}, {3, 19, 4, 0x0, 0}, OFPRAW_OFPST11_PORT_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_port_reply_instances[] = {
    { {0, NULL}, {4, 19, 4, 0x0, 0}, OFPRAW_OFPST13_PORT_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst14_port_reply_instances[] = {
    { {0, NULL}, {5, 19, 4, 0x0, 0}, OFPRAW_OFPST14_PORT_REPLY, 0 },
    { {0, NULL}, {6, 19, 4, 0x0, 0}, OFPRAW_OFPST14_PORT_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst10_queue_request_instances[] = {
    { {0, NULL}, {1, 16, 5, 0x0, 0}, OFPRAW_OFPST10_QUEUE_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst11_queue_request_instances[] = {
    { {0, NULL}, {2, 18, 5, 0x0, 0}, OFPRAW_OFPST11_QUEUE_REQUEST, 0 },
    { {0, NULL}, {3, 18, 5, 0x0, 0}, OFPRAW_OFPST11_QUEUE_REQUEST, 0 },
    { {0, NULL}, {4, 18, 5, 0x0, 0}, OFPRAW_OFPST11_QUEUE_REQUEST, 0 },
    { {0, NULL}, {5, 18, 5, 0x0, 0}, OFPRAW_OFPST11_QUEUE_REQUEST, 0 },
    { {0, NULL}, {6, 18, 5, 0x0, 0}, OFPRAW_OFPST11_QUEUE_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst10_queue_reply_instances[] = {
    { {0, NULL}, {1, 17, 5, 0x0, 0}, OFPRAW_OFPST10_QUEUE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst11_queue_reply_instances[] = {
    { {0, NULL}, {2, 19, 5, 0x0, 0}, OFPRAW_OFPST11_QUEUE_REPLY, 0 },
    { {0, NULL}, {3, 19, 5, 0x0, 0}, OFPRAW_OFPST11_QUEUE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_queue_reply_instances[] = {
    { {0, NULL}, {4, 19, 5, 0x0, 0}, OFPRAW_OFPST13_QUEUE_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst14_queue_reply_instances[] = {
    { {0, NULL}, {5, 19, 5, 0x0, 0}, OFPRAW_OFPST14_QUEUE_REPLY, 0 },
    { {0, NULL}, {6, 19, 5, 0x0, 0}, OFPRAW_OFPST14_QUEUE_REPLY, 0 },
};
static struct raw_instance ofpraw_nxst_group_request_instances[] = {
    { {0, NULL}, {1, 16, 65535, 0x2320, 7}, OFPRAW_NXST_GROUP_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst11_group_request_instances[] = {
    { {0, NULL}, {2, 18, 6, 0x0, 0}, OFPRAW_OFPST11_GROUP_REQUEST, 0 },
    { {0, NULL}, {3, 18, 6, 0x0, 0}, OFPRAW_OFPST11_GROUP_REQUEST, 0 },
    { {0, NULL}, {4, 18, 6, 0x0, 0}, OFPRAW_OFPST11_GROUP_REQUEST, 0 },
    { {0, NULL}, {5, 18, 6, 0x0, 0}, OFPRAW_OFPST11_GROUP_REQUEST, 0 },
    { {0, NULL}, {6, 18, 6, 0x0, 0}, OFPRAW_OFPST11_GROUP_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxst_group_reply_instances[] = {
    { {0, NULL}, {1, 17, 65535, 0x2320, 7}, OFPRAW_NXST_GROUP_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst11_group_reply_instances[] = {
    { {0, NULL}, {2, 19, 6, 0x0, 0}, OFPRAW_OFPST11_GROUP_REPLY, 0 },
    { {0, NULL}, {3, 19, 6, 0x0, 0}, OFPRAW_OFPST11_GROUP_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_group_reply_instances[] = {
    { {0, NULL}, {4, 19, 6, 0x0, 0}, OFPRAW_OFPST13_GROUP_REPLY, 0 },
    { {0, NULL}, {5, 19, 6, 0x0, 0}, OFPRAW_OFPST13_GROUP_REPLY, 0 },
    { {0, NULL}, {6, 19, 6, 0x0, 0}, OFPRAW_OFPST13_GROUP_REPLY, 0 },
};
static struct raw_instance ofpraw_nxst_group_desc_request_instances[] = {
    { {0, NULL}, {1, 16, 65535, 0x2320, 8}, OFPRAW_NXST_GROUP_DESC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst11_group_desc_request_instances[] = {
    { {0, NULL}, {2, 18, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REQUEST, 0 },
    { {0, NULL}, {3, 18, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REQUEST, 0 },
    { {0, NULL}, {4, 18, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REQUEST, 0 },
    { {0, NULL}, {5, 18, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst15_group_desc_request_instances[] = {
    { {0, NULL}, {6, 18, 7, 0x0, 0}, OFPRAW_OFPST15_GROUP_DESC_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxst_group_desc_reply_instances[] = {
    { {0, NULL}, {1, 17, 65535, 0x2320, 8}, OFPRAW_NXST_GROUP_DESC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst11_group_desc_reply_instances[] = {
    { {0, NULL}, {2, 19, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REPLY, 0 },
    { {0, NULL}, {3, 19, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REPLY, 0 },
    { {0, NULL}, {4, 19, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REPLY, 0 },
    { {0, NULL}, {5, 19, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REPLY, 0 },
    { {0, NULL}, {6, 19, 7, 0x0, 0}, OFPRAW_OFPST11_GROUP_DESC_REPLY, 0 },
};
static struct raw_instance ofpraw_nxst_group_features_request_instances[] = {
    { {0, NULL}, {1, 16, 65535, 0x2320, 9}, OFPRAW_NXST_GROUP_FEATURES_REQUEST, 0 },
    { {0, NULL}, {2, 18, 65535, 0x2320, 9}, OFPRAW_NXST_GROUP_FEATURES_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst12_group_features_request_instances[] = {
    { {0, NULL}, {3, 18, 8, 0x0, 0}, OFPRAW_OFPST12_GROUP_FEATURES_REQUEST, 0 },
    { {0, NULL}, {4, 18, 8, 0x0, 0}, OFPRAW_OFPST12_GROUP_FEATURES_REQUEST, 0 },
    { {0, NULL}, {5, 18, 8, 0x0, 0}, OFPRAW_OFPST12_GROUP_FEATURES_REQUEST, 0 },
    { {0, NULL}, {6, 18, 8, 0x0, 0}, OFPRAW_OFPST12_GROUP_FEATURES_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxst_group_features_reply_instances[] = {
    { {0, NULL}, {1, 17, 65535, 0x2320, 9}, OFPRAW_NXST_GROUP_FEATURES_REPLY, 0 },
    { {0, NULL}, {2, 19, 65535, 0x2320, 9}, OFPRAW_NXST_GROUP_FEATURES_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst12_group_features_reply_instances[] = {
    { {0, NULL}, {3, 19, 8, 0x0, 0}, OFPRAW_OFPST12_GROUP_FEATURES_REPLY, 0 },
    { {0, NULL}, {4, 19, 8, 0x0, 0}, OFPRAW_OFPST12_GROUP_FEATURES_REPLY, 0 },
    { {0, NULL}, {5, 19, 8, 0x0, 0}, OFPRAW_OFPST12_GROUP_FEATURES_REPLY, 0 },
    { {0, NULL}, {6, 19, 8, 0x0, 0}, OFPRAW_OFPST12_GROUP_FEATURES_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_meter_request_instances[] = {
    { {0, NULL}, {4, 18, 9, 0x0, 0}, OFPRAW_OFPST13_METER_REQUEST, 0 },
    { {0, NULL}, {5, 18, 9, 0x0, 0}, OFPRAW_OFPST13_METER_REQUEST, 0 },
    { {0, NULL}, {6, 18, 9, 0x0, 0}, OFPRAW_OFPST13_METER_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst13_meter_reply_instances[] = {
    { {0, NULL}, {4, 19, 9, 0x0, 0}, OFPRAW_OFPST13_METER_REPLY, 0 },
    { {0, NULL}, {5, 19, 9, 0x0, 0}, OFPRAW_OFPST13_METER_REPLY, 0 },
    { {0, NULL}, {6, 19, 9, 0x0, 0}, OFPRAW_OFPST13_METER_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_meter_config_request_instances[] = {
    { {0, NULL}, {4, 18, 10, 0x0, 0}, OFPRAW_OFPST13_METER_CONFIG_REQUEST, 0 },
    { {0, NULL}, {5, 18, 10, 0x0, 0}, OFPRAW_OFPST13_METER_CONFIG_REQUEST, 0 },
    { {0, NULL}, {6, 18, 10, 0x0, 0}, OFPRAW_OFPST13_METER_CONFIG_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst13_meter_config_reply_instances[] = {
    { {0, NULL}, {4, 19, 10, 0x0, 0}, OFPRAW_OFPST13_METER_CONFIG_REPLY, 0 },
    { {0, NULL}, {5, 19, 10, 0x0, 0}, OFPRAW_OFPST13_METER_CONFIG_REPLY, 0 },
    { {0, NULL}, {6, 19, 10, 0x0, 0}, OFPRAW_OFPST13_METER_CONFIG_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_meter_features_request_instances[] = {
    { {0, NULL}, {4, 18, 11, 0x0, 0}, OFPRAW_OFPST13_METER_FEATURES_REQUEST, 0 },
    { {0, NULL}, {5, 18, 11, 0x0, 0}, OFPRAW_OFPST13_METER_FEATURES_REQUEST, 0 },
    { {0, NULL}, {6, 18, 11, 0x0, 0}, OFPRAW_OFPST13_METER_FEATURES_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst13_meter_features_reply_instances[] = {
    { {0, NULL}, {4, 19, 11, 0x0, 0}, OFPRAW_OFPST13_METER_FEATURES_REPLY, 0 },
    { {0, NULL}, {5, 19, 11, 0x0, 0}, OFPRAW_OFPST13_METER_FEATURES_REPLY, 0 },
    { {0, NULL}, {6, 19, 11, 0x0, 0}, OFPRAW_OFPST13_METER_FEATURES_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst13_table_features_request_instances[] = {
    { {0, NULL}, {4, 18, 12, 0x0, 0}, OFPRAW_OFPST13_TABLE_FEATURES_REQUEST, 0 },
    { {0, NULL}, {5, 18, 12, 0x0, 0}, OFPRAW_OFPST13_TABLE_FEATURES_REQUEST, 0 },
    { {0, NULL}, {6, 18, 12, 0x0, 0}, OFPRAW_OFPST13_TABLE_FEATURES_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst13_table_features_reply_instances[] = {
    { {0, NULL}, {4, 19, 12, 0x0, 0}, OFPRAW_OFPST13_TABLE_FEATURES_REPLY, 0 },
    { {0, NULL}, {5, 19, 12, 0x0, 0}, OFPRAW_OFPST13_TABLE_FEATURES_REPLY, 0 },
    { {0, NULL}, {6, 19, 12, 0x0, 0}, OFPRAW_OFPST13_TABLE_FEATURES_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst14_table_desc_request_instances[] = {
    { {0, NULL}, {5, 18, 14, 0x0, 0}, OFPRAW_OFPST14_TABLE_DESC_REQUEST, 0 },
    { {0, NULL}, {6, 18, 14, 0x0, 0}, OFPRAW_OFPST14_TABLE_DESC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst14_table_desc_reply_instances[] = {
    { {0, NULL}, {5, 19, 14, 0x0, 0}, OFPRAW_OFPST14_TABLE_DESC_REPLY, 0 },
    { {0, NULL}, {6, 19, 14, 0x0, 0}, OFPRAW_OFPST14_TABLE_DESC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst10_port_desc_request_instances[] = {
    { {0, NULL}, {1, 16, 13, 0x0, 0}, OFPRAW_OFPST10_PORT_DESC_REQUEST, 0 },
    { {0, NULL}, {2, 18, 13, 0x0, 0}, OFPRAW_OFPST10_PORT_DESC_REQUEST, 0 },
    { {0, NULL}, {3, 18, 13, 0x0, 0}, OFPRAW_OFPST10_PORT_DESC_REQUEST, 0 },
    { {0, NULL}, {4, 18, 13, 0x0, 0}, OFPRAW_OFPST10_PORT_DESC_REQUEST, 0 },
    { {0, NULL}, {5, 18, 13, 0x0, 0}, OFPRAW_OFPST10_PORT_DESC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst15_port_desc_request_instances[] = {
    { {0, NULL}, {6, 18, 13, 0x0, 0}, OFPRAW_OFPST15_PORT_DESC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst10_port_desc_reply_instances[] = {
    { {0, NULL}, {1, 17, 13, 0x0, 0}, OFPRAW_OFPST10_PORT_DESC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst11_port_desc_reply_instances[] = {
    { {0, NULL}, {2, 19, 13, 0x0, 0}, OFPRAW_OFPST11_PORT_DESC_REPLY, 0 },
    { {0, NULL}, {3, 19, 13, 0x0, 0}, OFPRAW_OFPST11_PORT_DESC_REPLY, 0 },
    { {0, NULL}, {4, 19, 13, 0x0, 0}, OFPRAW_OFPST11_PORT_DESC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst14_port_desc_reply_instances[] = {
    { {0, NULL}, {5, 19, 13, 0x0, 0}, OFPRAW_OFPST14_PORT_DESC_REPLY, 0 },
    { {0, NULL}, {6, 19, 13, 0x0, 0}, OFPRAW_OFPST14_PORT_DESC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst14_queue_desc_request_instances[] = {
    { {0, NULL}, {5, 18, 15, 0x0, 0}, OFPRAW_OFPST14_QUEUE_DESC_REQUEST, 0 },
    { {0, NULL}, {6, 18, 15, 0x0, 0}, OFPRAW_OFPST14_QUEUE_DESC_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst14_queue_desc_reply_instances[] = {
    { {0, NULL}, {5, 19, 15, 0x0, 0}, OFPRAW_OFPST14_QUEUE_DESC_REPLY, 0 },
    { {0, NULL}, {6, 19, 15, 0x0, 0}, OFPRAW_OFPST14_QUEUE_DESC_REPLY, 0 },
};
static struct raw_instance ofpraw_ofpst14_flow_monitor_request_instances[] = {
    { {0, NULL}, {5, 18, 16, 0x0, 0}, OFPRAW_OFPST14_FLOW_MONITOR_REQUEST, 0 },
    { {0, NULL}, {6, 18, 16, 0x0, 0}, OFPRAW_OFPST14_FLOW_MONITOR_REQUEST, 0 },
};
static struct raw_instance ofpraw_onfst13_flow_monitor_request_instances[] = {
    { {0, NULL}, {4, 18, 65535, 0x4f4e4600, 1870}, OFPRAW_ONFST13_FLOW_MONITOR_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxst_flow_monitor_request_instances[] = {
    { {0, NULL}, {1, 16, 65535, 0x2320, 2}, OFPRAW_NXST_FLOW_MONITOR_REQUEST, 0 },
    { {0, NULL}, {2, 18, 65535, 0x2320, 2}, OFPRAW_NXST_FLOW_MONITOR_REQUEST, 0 },
    { {0, NULL}, {3, 18, 65535, 0x2320, 2}, OFPRAW_NXST_FLOW_MONITOR_REQUEST, 0 },
};
static struct raw_instance ofpraw_ofpst14_flow_monitor_reply_instances[] = {
    { {0, NULL}, {5, 19, 16, 0x0, 0}, OFPRAW_OFPST14_FLOW_MONITOR_REPLY, 0 },
    { {0, NULL}, {6, 19, 16, 0x0, 0}, OFPRAW_OFPST14_FLOW_MONITOR_REPLY, 0 },
};
static struct raw_instance ofpraw_onfst13_flow_monitor_reply_instances[] = {
    { {0, NULL}, {4, 19, 65535, 0x4f4e4600, 1870}, OFPRAW_ONFST13_FLOW_MONITOR_REPLY, 0 },
};
static struct raw_instance ofpraw_nxst_flow_monitor_reply_instances[] = {
    { {0, NULL}, {1, 17, 65535, 0x2320, 2}, OFPRAW_NXST_FLOW_MONITOR_REPLY, 0 },
    { {0, NULL}, {2, 19, 65535, 0x2320, 2}, OFPRAW_NXST_FLOW_MONITOR_REPLY, 0 },
    { {0, NULL}, {3, 19, 65535, 0x2320, 2}, OFPRAW_NXST_FLOW_MONITOR_REPLY, 0 },
};
static struct raw_instance ofpraw_onft13_flow_monitor_cancel_instances[] = {
    { {0, NULL}, {4, 4, 0, 0x4f4e4600, 1870}, OFPRAW_ONFT13_FLOW_MONITOR_CANCEL, 0 },
};
static struct raw_instance ofpraw_nxt_flow_monitor_cancel_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 21}, OFPRAW_NXT_FLOW_MONITOR_CANCEL, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 21}, OFPRAW_NXT_FLOW_MONITOR_CANCEL, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 21}, OFPRAW_NXT_FLOW_MONITOR_CANCEL, 0 },
};
static struct raw_instance ofpraw_onft13_flow_monitor_paused_instances[] = {
    { {0, NULL}, {4, 4, 0, 0x4f4e4600, 1871}, OFPRAW_ONFT13_FLOW_MONITOR_PAUSED, 0 },
};
static struct raw_instance ofpraw_nxt_flow_monitor_paused_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 22}, OFPRAW_NXT_FLOW_MONITOR_PAUSED, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 22}, OFPRAW_NXT_FLOW_MONITOR_PAUSED, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 22}, OFPRAW_NXT_FLOW_MONITOR_PAUSED, 0 },
};
static struct raw_instance ofpraw_onft13_flow_monitor_resumed_instances[] = {
    { {0, NULL}, {4, 4, 0, 0x4f4e4600, 1872}, OFPRAW_ONFT13_FLOW_MONITOR_RESUMED, 0 },
};
static struct raw_instance ofpraw_nxt_flow_monitor_resumed_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 23}, OFPRAW_NXT_FLOW_MONITOR_RESUMED, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 23}, OFPRAW_NXT_FLOW_MONITOR_RESUMED, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 23}, OFPRAW_NXT_FLOW_MONITOR_RESUMED, 0 },
};
static struct raw_instance ofpraw_nxt_set_flow_format_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 12}, OFPRAW_NXT_SET_FLOW_FORMAT, 0 },
};
static struct raw_instance ofpraw_nxt_flow_mod_table_id_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 15}, OFPRAW_NXT_FLOW_MOD_TABLE_ID, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 15}, OFPRAW_NXT_FLOW_MOD_TABLE_ID, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 15}, OFPRAW_NXT_FLOW_MOD_TABLE_ID, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 15}, OFPRAW_NXT_FLOW_MOD_TABLE_ID, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 15}, OFPRAW_NXT_FLOW_MOD_TABLE_ID, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 15}, OFPRAW_NXT_FLOW_MOD_TABLE_ID, 0 },
};
static struct raw_instance ofpraw_nxt_set_packet_in_format_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 16}, OFPRAW_NXT_SET_PACKET_IN_FORMAT, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 16}, OFPRAW_NXT_SET_PACKET_IN_FORMAT, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 16}, OFPRAW_NXT_SET_PACKET_IN_FORMAT, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 16}, OFPRAW_NXT_SET_PACKET_IN_FORMAT, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 16}, OFPRAW_NXT_SET_PACKET_IN_FORMAT, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 16}, OFPRAW_NXT_SET_PACKET_IN_FORMAT, 0 },
};
static struct raw_instance ofpraw_nxt_flow_age_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 18}, OFPRAW_NXT_FLOW_AGE, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 18}, OFPRAW_NXT_FLOW_AGE, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 18}, OFPRAW_NXT_FLOW_AGE, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 18}, OFPRAW_NXT_FLOW_AGE, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 18}, OFPRAW_NXT_FLOW_AGE, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 18}, OFPRAW_NXT_FLOW_AGE, 0 },
};
static struct raw_instance ofpraw_nxt_set_controller_id_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 20}, OFPRAW_NXT_SET_CONTROLLER_ID, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 20}, OFPRAW_NXT_SET_CONTROLLER_ID, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 20}, OFPRAW_NXT_SET_CONTROLLER_ID, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 20}, OFPRAW_NXT_SET_CONTROLLER_ID, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 20}, OFPRAW_NXT_SET_CONTROLLER_ID, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 20}, OFPRAW_NXT_SET_CONTROLLER_ID, 0 },
};
static struct raw_instance ofpraw_nxt_tlv_table_mod_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 24}, OFPRAW_NXT_TLV_TABLE_MOD, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 24}, OFPRAW_NXT_TLV_TABLE_MOD, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 24}, OFPRAW_NXT_TLV_TABLE_MOD, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 24}, OFPRAW_NXT_TLV_TABLE_MOD, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 24}, OFPRAW_NXT_TLV_TABLE_MOD, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 24}, OFPRAW_NXT_TLV_TABLE_MOD, 0 },
};
static struct raw_instance ofpraw_nxt_tlv_table_request_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 25}, OFPRAW_NXT_TLV_TABLE_REQUEST, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 25}, OFPRAW_NXT_TLV_TABLE_REQUEST, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 25}, OFPRAW_NXT_TLV_TABLE_REQUEST, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 25}, OFPRAW_NXT_TLV_TABLE_REQUEST, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 25}, OFPRAW_NXT_TLV_TABLE_REQUEST, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 25}, OFPRAW_NXT_TLV_TABLE_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxt_tlv_table_reply_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 26}, OFPRAW_NXT_TLV_TABLE_REPLY, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 26}, OFPRAW_NXT_TLV_TABLE_REPLY, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 26}, OFPRAW_NXT_TLV_TABLE_REPLY, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 26}, OFPRAW_NXT_TLV_TABLE_REPLY, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 26}, OFPRAW_NXT_TLV_TABLE_REPLY, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 26}, OFPRAW_NXT_TLV_TABLE_REPLY, 0 },
};
static struct raw_instance ofpraw_nxt_resume_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 28}, OFPRAW_NXT_RESUME, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 28}, OFPRAW_NXT_RESUME, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 28}, OFPRAW_NXT_RESUME, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 28}, OFPRAW_NXT_RESUME, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 28}, OFPRAW_NXT_RESUME, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 28}, OFPRAW_NXT_RESUME, 0 },
};
static struct raw_instance ofpraw_nxt_ct_flush_zone_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 29}, OFPRAW_NXT_CT_FLUSH_ZONE, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 29}, OFPRAW_NXT_CT_FLUSH_ZONE, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 29}, OFPRAW_NXT_CT_FLUSH_ZONE, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 29}, OFPRAW_NXT_CT_FLUSH_ZONE, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 29}, OFPRAW_NXT_CT_FLUSH_ZONE, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 29}, OFPRAW_NXT_CT_FLUSH_ZONE, 0 },
};
static struct raw_instance ofpraw_nxt_ct_flush_instances[] = {
    { {0, NULL}, {1, 4, 0, 0x2320, 32}, OFPRAW_NXT_CT_FLUSH, 0 },
    { {0, NULL}, {2, 4, 0, 0x2320, 32}, OFPRAW_NXT_CT_FLUSH, 0 },
    { {0, NULL}, {3, 4, 0, 0x2320, 32}, OFPRAW_NXT_CT_FLUSH, 0 },
    { {0, NULL}, {4, 4, 0, 0x2320, 32}, OFPRAW_NXT_CT_FLUSH, 0 },
    { {0, NULL}, {5, 4, 0, 0x2320, 32}, OFPRAW_NXT_CT_FLUSH, 0 },
    { {0, NULL}, {6, 4, 0, 0x2320, 32}, OFPRAW_NXT_CT_FLUSH, 0 },
};
static struct raw_instance ofpraw_nxst_ipfix_bridge_request_instances[] = {
    { {0, NULL}, {1, 16, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REQUEST, 0 },
    { {0, NULL}, {2, 18, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REQUEST, 0 },
    { {0, NULL}, {3, 18, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REQUEST, 0 },
    { {0, NULL}, {4, 18, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REQUEST, 0 },
    { {0, NULL}, {5, 18, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REQUEST, 0 },
    { {0, NULL}, {6, 18, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxst_ipfix_bridge_reply_instances[] = {
    { {0, NULL}, {1, 17, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REPLY, 0 },
    { {0, NULL}, {2, 19, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REPLY, 0 },
    { {0, NULL}, {3, 19, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REPLY, 0 },
    { {0, NULL}, {4, 19, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REPLY, 0 },
    { {0, NULL}, {5, 19, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REPLY, 0 },
    { {0, NULL}, {6, 19, 65535, 0x2320, 3}, OFPRAW_NXST_IPFIX_BRIDGE_REPLY, 0 },
};
static struct raw_instance ofpraw_nxst_ipfix_flow_request_instances[] = {
    { {0, NULL}, {1, 16, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REQUEST, 0 },
    { {0, NULL}, {2, 18, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REQUEST, 0 },
    { {0, NULL}, {3, 18, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REQUEST, 0 },
    { {0, NULL}, {4, 18, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REQUEST, 0 },
    { {0, NULL}, {5, 18, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REQUEST, 0 },
    { {0, NULL}, {6, 18, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REQUEST, 0 },
};
static struct raw_instance ofpraw_nxst_ipfix_flow_reply_instances[] = {
    { {0, NULL}, {1, 17, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REPLY, 0 },
    { {0, NULL}, {2, 19, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REPLY, 0 },
    { {0, NULL}, {3, 19, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REPLY, 0 },
    { {0, NULL}, {4, 19, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REPLY, 0 },
    { {0, NULL}, {5, 19, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REPLY, 0 },
    { {0, NULL}, {6, 19, 65535, 0x2320, 4}, OFPRAW_NXST_IPFIX_FLOW_REPLY, 0 },
};

static struct raw_info raw_infos[] = {
    {
        ofpraw_ofpt_hello_instances,
        1, 255,
#line 118 "./include/openvswitch/ofp-msgs.h"
        0,
#line 118 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1800 "lib/ofp-msgs.inc"
        OFPTYPE_HELLO,
        "OFPT_HELLO",
    },
    {
        ofpraw_ofpt_error_instances,
        1, 255,
#line 121 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_error_msg),
#line 121 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1811 "lib/ofp-msgs.inc"
        OFPTYPE_ERROR,
        "OFPT_ERROR",
    },
    {
        ofpraw_ofpt_echo_request_instances,
        1, 255,
#line 124 "./include/openvswitch/ofp-msgs.h"
        0,
#line 124 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1822 "lib/ofp-msgs.inc"
        OFPTYPE_ECHO_REQUEST,
        "OFPT_ECHO_REQUEST",
    },
    {
        ofpraw_ofpt_echo_reply_instances,
        1, 255,
#line 127 "./include/openvswitch/ofp-msgs.h"
        0,
#line 127 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1833 "lib/ofp-msgs.inc"
        OFPTYPE_ECHO_REPLY,
        "OFPT_ECHO_REPLY",
    },
    {
        ofpraw_ofpt_features_request_instances,
        1, 6,
#line 135 "./include/openvswitch/ofp-msgs.h"
        0,
#line 135 "./include/openvswitch/ofp-msgs.h"
        0,
#line 1844 "lib/ofp-msgs.inc"
        OFPTYPE_FEATURES_REQUEST,
        "OFPT_FEATURES_REQUEST",
    },
    {
        ofpraw_ofpt10_features_reply_instances,
        1, 1,
#line 138 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_switch_features),
#line 138 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_phy_port),
#line 1855 "lib/ofp-msgs.inc"
        OFPTYPE_FEATURES_REPLY,
        "OFPT_FEATURES_REPLY",
    },
    {
        ofpraw_ofpt11_features_reply_instances,
        2, 3,
#line 140 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_switch_features),
#line 140 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_port),
#line 1866 "lib/ofp-msgs.inc"
        OFPTYPE_FEATURES_REPLY,
        "OFPT_FEATURES_REPLY",
    },
    {
        ofpraw_ofpt13_features_reply_instances,
        4, 6,
#line 142 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_switch_features),
#line 142 "./include/openvswitch/ofp-msgs.h"
        0,
#line 1877 "lib/ofp-msgs.inc"
        OFPTYPE_FEATURES_REPLY,
        "OFPT_FEATURES_REPLY",
    },
    {
        ofpraw_ofpt_get_config_request_instances,
        1, 6,
#line 145 "./include/openvswitch/ofp-msgs.h"
        0,
#line 145 "./include/openvswitch/ofp-msgs.h"
        0,
#line 1888 "lib/ofp-msgs.inc"
        OFPTYPE_GET_CONFIG_REQUEST,
        "OFPT_GET_CONFIG_REQUEST",
    },
    {
        ofpraw_ofpt_get_config_reply_instances,
        1, 6,
#line 148 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_switch_config),
#line 148 "./include/openvswitch/ofp-msgs.h"
        0,
#line 1899 "lib/ofp-msgs.inc"
        OFPTYPE_GET_CONFIG_REPLY,
        "OFPT_GET_CONFIG_REPLY",
    },
    {
        ofpraw_ofpt_set_config_instances,
        1, 6,
#line 151 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_switch_config),
#line 151 "./include/openvswitch/ofp-msgs.h"
        0,
#line 1910 "lib/ofp-msgs.inc"
        OFPTYPE_SET_CONFIG,
        "OFPT_SET_CONFIG",
    },
    {
        ofpraw_ofpt10_packet_in_instances,
        1, 1,
#line 154 "./include/openvswitch/ofp-msgs.h"
        offsetof(struct ofp10_packet_in, data),
#line 154 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1921 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_IN,
        "OFPT_PACKET_IN",
    },
    {
        ofpraw_ofpt11_packet_in_instances,
        2, 2,
#line 156 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_packet_in),
#line 156 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1932 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_IN,
        "OFPT_PACKET_IN",
    },
    {
        ofpraw_ofpt12_packet_in_instances,
        3, 3,
#line 158 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp12_packet_in),
#line 158 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1943 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_IN,
        "OFPT_PACKET_IN",
    },
    {
        ofpraw_ofpt13_packet_in_instances,
        4, 6,
#line 160 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp12_packet_in) + sizeof(ovs_be64),
#line 160 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1954 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_IN,
        "OFPT_PACKET_IN",
    },
    {
        ofpraw_nxt_packet_in_instances,
        1, 6,
#line 162 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_packet_in),
#line 162 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 1965 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_IN,
        "NXT_PACKET_IN",
    },
    {
        ofpraw_nxt_packet_in2_instances,
        1, 6,
#line 164 "./include/openvswitch/ofp-msgs.h"
        0,
#line 164 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 1976 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_IN,
        "NXT_PACKET_IN2",
    },
    {
        ofpraw_ofpt10_flow_removed_instances,
        1, 1,
#line 167 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_flow_removed),
#line 167 "./include/openvswitch/ofp-msgs.h"
        0,
#line 1987 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_REMOVED,
        "OFPT_FLOW_REMOVED",
    },
    {
        ofpraw_ofpt11_flow_removed_instances,
        2, 5,
#line 169 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_flow_removed),
#line 169 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 1998 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_REMOVED,
        "OFPT_FLOW_REMOVED",
    },
    {
        ofpraw_ofpt15_flow_removed_instances,
        6, 6,
#line 171 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp15_flow_removed),
#line 171 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2009 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_REMOVED,
        "OFPT_FLOW_REMOVED",
    },
    {
        ofpraw_nxt_flow_removed_instances,
        1, 6,
#line 173 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_flow_removed),
#line 173 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2020 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_REMOVED,
        "NXT_FLOW_REMOVED",
    },
    {
        ofpraw_ofpt10_port_status_instances,
        1, 1,
#line 176 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_port_status) + sizeof(struct ofp10_phy_port),
#line 176 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2031 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATUS,
        "OFPT_PORT_STATUS",
    },
    {
        ofpraw_ofpt11_port_status_instances,
        2, 4,
#line 178 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_port_status) + sizeof(struct ofp11_port),
#line 178 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2042 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATUS,
        "OFPT_PORT_STATUS",
    },
    {
        ofpraw_ofpt14_port_status_instances,
        5, 6,
#line 180 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_port_status) + sizeof(struct ofp14_port),
#line 180 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2053 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATUS,
        "OFPT_PORT_STATUS",
    },
    {
        ofpraw_ofpt10_packet_out_instances,
        1, 1,
#line 183 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_packet_out),
#line 183 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2064 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_OUT,
        "OFPT_PACKET_OUT",
    },
    {
        ofpraw_ofpt11_packet_out_instances,
        2, 5,
#line 185 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_packet_out),
#line 185 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2075 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_OUT,
        "OFPT_PACKET_OUT",
    },
    {
        ofpraw_ofpt15_packet_out_instances,
        6, 6,
#line 187 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp15_packet_out),
#line 187 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2086 "lib/ofp-msgs.inc"
        OFPTYPE_PACKET_OUT,
        "OFPT_PACKET_OUT",
    },
    {
        ofpraw_ofpt10_flow_mod_instances,
        1, 1,
#line 190 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_flow_mod),
#line 190 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2097 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MOD,
        "OFPT_FLOW_MOD",
    },
    {
        ofpraw_ofpt11_flow_mod_instances,
        2, 6,
#line 192 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_flow_mod),
#line 192 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_instruction),
#line 2108 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MOD,
        "OFPT_FLOW_MOD",
    },
    {
        ofpraw_nxt_flow_mod_instances,
        1, 6,
#line 194 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_flow_mod),
#line 194 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2119 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MOD,
        "NXT_FLOW_MOD",
    },
    {
        ofpraw_nxt_group_mod_instances,
        1, 1,
#line 197 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp15_group_mod),
#line 197 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2130 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_MOD,
        "NXT_GROUP_MOD",
    },
    {
        ofpraw_ofpt11_group_mod_instances,
        2, 5,
#line 199 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_group_mod),
#line 199 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2141 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_MOD,
        "OFPT_GROUP_MOD",
    },
    {
        ofpraw_ofpt15_group_mod_instances,
        6, 6,
#line 201 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp15_group_mod),
#line 201 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2152 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_MOD,
        "OFPT_GROUP_MOD",
    },
    {
        ofpraw_ofpt10_port_mod_instances,
        1, 1,
#line 204 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_port_mod),
#line 204 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2163 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_MOD,
        "OFPT_PORT_MOD",
    },
    {
        ofpraw_ofpt11_port_mod_instances,
        2, 4,
#line 206 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_port_mod),
#line 206 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2174 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_MOD,
        "OFPT_PORT_MOD",
    },
    {
        ofpraw_ofpt14_port_mod_instances,
        5, 6,
#line 208 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_port_mod),
#line 208 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2185 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_MOD,
        "OFPT_PORT_MOD",
    },
    {
        ofpraw_ofpt11_table_mod_instances,
        2, 4,
#line 211 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_table_mod),
#line 211 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2196 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_MOD,
        "OFPT_TABLE_MOD",
    },
    {
        ofpraw_ofpt14_table_mod_instances,
        5, 6,
#line 213 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_table_mod),
#line 213 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2207 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_MOD,
        "OFPT_TABLE_MOD",
    },
    {
        ofpraw_ofpt10_barrier_request_instances,
        1, 1,
#line 216 "./include/openvswitch/ofp-msgs.h"
        0,
#line 216 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2218 "lib/ofp-msgs.inc"
        OFPTYPE_BARRIER_REQUEST,
        "OFPT_BARRIER_REQUEST",
    },
    {
        ofpraw_ofpt11_barrier_request_instances,
        2, 6,
#line 218 "./include/openvswitch/ofp-msgs.h"
        0,
#line 218 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2229 "lib/ofp-msgs.inc"
        OFPTYPE_BARRIER_REQUEST,
        "OFPT_BARRIER_REQUEST",
    },
    {
        ofpraw_ofpt10_barrier_reply_instances,
        1, 1,
#line 221 "./include/openvswitch/ofp-msgs.h"
        0,
#line 221 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2240 "lib/ofp-msgs.inc"
        OFPTYPE_BARRIER_REPLY,
        "OFPT_BARRIER_REPLY",
    },
    {
        ofpraw_ofpt11_barrier_reply_instances,
        2, 6,
#line 223 "./include/openvswitch/ofp-msgs.h"
        0,
#line 223 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2251 "lib/ofp-msgs.inc"
        OFPTYPE_BARRIER_REPLY,
        "OFPT_BARRIER_REPLY",
    },
    {
        ofpraw_ofpt10_queue_get_config_request_instances,
        1, 1,
#line 226 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_queue_get_config_request),
#line 226 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2262 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_GET_CONFIG_REQUEST,
        "OFPT_QUEUE_GET_CONFIG_REQUEST",
    },
    {
        ofpraw_ofpt11_queue_get_config_request_instances,
        2, 4,
#line 228 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_queue_get_config_request),
#line 228 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2273 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_GET_CONFIG_REQUEST,
        "OFPT_QUEUE_GET_CONFIG_REQUEST",
    },
    {
        ofpraw_ofpt10_queue_get_config_reply_instances,
        1, 1,
#line 231 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_queue_get_config_reply),
#line 231 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2284 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_GET_CONFIG_REPLY,
        "OFPT_QUEUE_GET_CONFIG_REPLY",
    },
    {
        ofpraw_ofpt11_queue_get_config_reply_instances,
        2, 4,
#line 233 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_queue_get_config_reply),
#line 233 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2295 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_GET_CONFIG_REPLY,
        "OFPT_QUEUE_GET_CONFIG_REPLY",
    },
    {
        ofpraw_ofpt12_role_request_instances,
        3, 6,
#line 236 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp12_role_request),
#line 236 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2306 "lib/ofp-msgs.inc"
        OFPTYPE_ROLE_REQUEST,
        "OFPT_ROLE_REQUEST",
    },
    {
        ofpraw_nxt_role_request_instances,
        1, 6,
#line 238 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_role_request),
#line 238 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2317 "lib/ofp-msgs.inc"
        OFPTYPE_ROLE_REQUEST,
        "NXT_ROLE_REQUEST",
    },
    {
        ofpraw_ofpt12_role_reply_instances,
        3, 6,
#line 241 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp12_role_request),
#line 241 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2328 "lib/ofp-msgs.inc"
        OFPTYPE_ROLE_REPLY,
        "OFPT_ROLE_REPLY",
    },
    {
        ofpraw_nxt_role_reply_instances,
        1, 6,
#line 243 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_role_request),
#line 243 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2339 "lib/ofp-msgs.inc"
        OFPTYPE_ROLE_REPLY,
        "NXT_ROLE_REPLY",
    },
    {
        ofpraw_ofpt13_get_async_request_instances,
        4, 4,
#line 246 "./include/openvswitch/ofp-msgs.h"
        0,
#line 246 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2350 "lib/ofp-msgs.inc"
        OFPTYPE_GET_ASYNC_REQUEST,
        "OFPT_GET_ASYNC_REQUEST",
    },
    {
        ofpraw_ofpt14_get_async_request_instances,
        5, 6,
#line 248 "./include/openvswitch/ofp-msgs.h"
        0,
#line 248 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2361 "lib/ofp-msgs.inc"
        OFPTYPE_GET_ASYNC_REQUEST,
        "OFPT_GET_ASYNC_REQUEST",
    },
    {
        ofpraw_ofpt13_get_async_reply_instances,
        4, 4,
#line 250 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_async_config),
#line 250 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2372 "lib/ofp-msgs.inc"
        OFPTYPE_GET_ASYNC_REPLY,
        "OFPT_GET_ASYNC_REPLY",
    },
    {
        ofpraw_ofpt14_get_async_reply_instances,
        5, 6,
#line 252 "./include/openvswitch/ofp-msgs.h"
        0,
#line 252 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2383 "lib/ofp-msgs.inc"
        OFPTYPE_GET_ASYNC_REPLY,
        "OFPT_GET_ASYNC_REPLY",
    },
    {
        ofpraw_ofpt13_set_async_instances,
        4, 4,
#line 254 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_async_config),
#line 254 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2394 "lib/ofp-msgs.inc"
        OFPTYPE_SET_ASYNC_CONFIG,
        "OFPT_SET_ASYNC",
    },
    {
        ofpraw_nxt_set_async_config_instances,
        1, 6,
#line 256 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_async_config),
#line 256 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2405 "lib/ofp-msgs.inc"
        OFPTYPE_SET_ASYNC_CONFIG,
        "NXT_SET_ASYNC_CONFIG",
    },
    {
        ofpraw_nxt_set_async_config2_instances,
        1, 4,
#line 258 "./include/openvswitch/ofp-msgs.h"
        0,
#line 258 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2416 "lib/ofp-msgs.inc"
        OFPTYPE_SET_ASYNC_CONFIG,
        "NXT_SET_ASYNC_CONFIG2",
    },
    {
        ofpraw_ofpt14_set_async_instances,
        5, 6,
#line 260 "./include/openvswitch/ofp-msgs.h"
        0,
#line 260 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2427 "lib/ofp-msgs.inc"
        OFPTYPE_SET_ASYNC_CONFIG,
        "OFPT_SET_ASYNC",
    },
    {
        ofpraw_ofpt13_meter_mod_instances,
        4, 6,
#line 263 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_meter_mod),
#line 263 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2438 "lib/ofp-msgs.inc"
        OFPTYPE_METER_MOD,
        "OFPT_METER_MOD",
    },
    {
        ofpraw_onft13_role_status_instances,
        4, 4,
#line 266 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_role_status),
#line 266 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2449 "lib/ofp-msgs.inc"
        OFPTYPE_ROLE_STATUS,
        "ONFT_ROLE_STATUS",
    },
    {
        ofpraw_ofpt14_role_status_instances,
        5, 6,
#line 268 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_role_status),
#line 268 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2460 "lib/ofp-msgs.inc"
        OFPTYPE_ROLE_STATUS,
        "OFPT_ROLE_STATUS",
    },
    {
        ofpraw_ofpt14_table_status_instances,
        5, 6,
#line 271 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_table_status),
#line 271 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2471 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_STATUS,
        "OFPT_TABLE_STATUS",
    },
    {
        ofpraw_nxt_requestforward_instances,
        1, 3,
#line 274 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_requestforward),
#line 274 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2482 "lib/ofp-msgs.inc"
        OFPTYPE_REQUESTFORWARD,
        "NXT_REQUESTFORWARD",
    },
    {
        ofpraw_onft13_requestforward_instances,
        4, 4,
#line 276 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_requestforward),
#line 276 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2493 "lib/ofp-msgs.inc"
        OFPTYPE_REQUESTFORWARD,
        "ONFT_REQUESTFORWARD",
    },
    {
        ofpraw_ofpt14_requestforward_instances,
        5, 6,
#line 278 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_requestforward),
#line 278 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2504 "lib/ofp-msgs.inc"
        OFPTYPE_REQUESTFORWARD,
        "OFPT_REQUESTFORWARD",
    },
    {
        ofpraw_ofpt14_bundle_control_instances,
        5, 6,
#line 281 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_bundle_ctrl_msg),
#line 281 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2515 "lib/ofp-msgs.inc"
        OFPTYPE_BUNDLE_CONTROL,
        "OFPT_BUNDLE_CONTROL",
    },
    {
        ofpraw_onft13_bundle_control_instances,
        4, 4,
#line 283 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_bundle_ctrl_msg),
#line 283 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2526 "lib/ofp-msgs.inc"
        OFPTYPE_BUNDLE_CONTROL,
        "ONFT_BUNDLE_CONTROL",
    },
    {
        ofpraw_ofpt14_bundle_add_message_instances,
        5, 6,
#line 286 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_bundle_ctrl_msg),
#line 286 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2537 "lib/ofp-msgs.inc"
        OFPTYPE_BUNDLE_ADD_MESSAGE,
        "OFPT_BUNDLE_ADD_MESSAGE",
    },
    {
        ofpraw_onft13_bundle_add_message_instances,
        4, 4,
#line 288 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_bundle_ctrl_msg),
#line 288 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2548 "lib/ofp-msgs.inc"
        OFPTYPE_BUNDLE_ADD_MESSAGE,
        "ONFT_BUNDLE_ADD_MESSAGE",
    },
    {
        ofpraw_ofpst_desc_request_instances,
        1, 6,
#line 293 "./include/openvswitch/ofp-msgs.h"
        0,
#line 293 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2559 "lib/ofp-msgs.inc"
        OFPTYPE_DESC_STATS_REQUEST,
        "OFPST_DESC request",
    },
    {
        ofpraw_ofpst_desc_reply_instances,
        1, 6,
#line 296 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_desc_stats),
#line 296 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2570 "lib/ofp-msgs.inc"
        OFPTYPE_DESC_STATS_REPLY,
        "OFPST_DESC reply",
    },
    {
        ofpraw_ofpst10_flow_request_instances,
        1, 1,
#line 299 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_flow_stats_request),
#line 299 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2581 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_STATS_REQUEST,
        "OFPST_FLOW request",
    },
    {
        ofpraw_ofpst11_flow_request_instances,
        2, 6,
#line 301 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_flow_stats_request),
#line 301 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2592 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_STATS_REQUEST,
        "OFPST_FLOW request",
    },
    {
        ofpraw_nxst_flow_request_instances,
        1, 1,
#line 303 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_flow_stats_request),
#line 303 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2603 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_STATS_REQUEST,
        "NXST_FLOW request",
    },
    {
        ofpraw_ofpst10_flow_reply_instances,
        1, 1,
#line 306 "./include/openvswitch/ofp-msgs.h"
        0,
#line 306 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2614 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_STATS_REPLY,
        "OFPST_FLOW reply",
    },
    {
        ofpraw_ofpst11_flow_reply_instances,
        2, 3,
#line 308 "./include/openvswitch/ofp-msgs.h"
        0,
#line 308 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2625 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_STATS_REPLY,
        "OFPST_FLOW reply",
    },
    {
        ofpraw_ofpst13_flow_reply_instances,
        4, 5,
#line 310 "./include/openvswitch/ofp-msgs.h"
        0,
#line 310 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2636 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_STATS_REPLY,
        "OFPST_FLOW reply",
    },
    {
        ofpraw_ofpst15_flow_reply_instances,
        6, 6,
#line 312 "./include/openvswitch/ofp-msgs.h"
        0,
#line 312 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2647 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_STATS_REPLY,
        "OFPST_FLOW reply",
    },
    {
        ofpraw_nxst_flow_reply_instances,
        1, 1,
#line 314 "./include/openvswitch/ofp-msgs.h"
        0,
#line 314 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2658 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_STATS_REPLY,
        "NXST_FLOW reply",
    },
    {
        ofpraw_ofpst10_aggregate_request_instances,
        1, 1,
#line 317 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_flow_stats_request),
#line 317 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2669 "lib/ofp-msgs.inc"
        OFPTYPE_AGGREGATE_STATS_REQUEST,
        "OFPST_AGGREGATE request",
    },
    {
        ofpraw_ofpst11_aggregate_request_instances,
        2, 5,
#line 319 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_flow_stats_request),
#line 319 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2680 "lib/ofp-msgs.inc"
        OFPTYPE_AGGREGATE_STATS_REQUEST,
        "OFPST_AGGREGATE request",
    },
    {
        ofpraw_ofpst15_aggregate_request_instances,
        6, 6,
#line 321 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_flow_stats_request),
#line 321 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2691 "lib/ofp-msgs.inc"
        OFPTYPE_AGGREGATE_STATS_REQUEST,
        "OFPST_AGGREGATE request",
    },
    {
        ofpraw_nxst_aggregate_request_instances,
        1, 1,
#line 323 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_flow_stats_request),
#line 323 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2702 "lib/ofp-msgs.inc"
        OFPTYPE_AGGREGATE_STATS_REQUEST,
        "NXST_AGGREGATE request",
    },
    {
        ofpraw_ofpst_aggregate_reply_instances,
        1, 5,
#line 326 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_aggregate_stats_reply),
#line 326 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2713 "lib/ofp-msgs.inc"
        OFPTYPE_AGGREGATE_STATS_REPLY,
        "OFPST_AGGREGATE reply",
    },
    {
        ofpraw_ofpst15_aggregate_reply_instances,
        6, 6,
#line 328 "./include/openvswitch/ofp-msgs.h"
        0,
#line 328 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t),
#line 2724 "lib/ofp-msgs.inc"
        OFPTYPE_AGGREGATE_STATS_REPLY,
        "OFPST_AGGREGATE reply",
    },
    {
        ofpraw_nxst_aggregate_reply_instances,
        1, 1,
#line 330 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp_aggregate_stats_reply),
#line 330 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2735 "lib/ofp-msgs.inc"
        OFPTYPE_AGGREGATE_STATS_REPLY,
        "NXST_AGGREGATE reply",
    },
    {
        ofpraw_ofpst_table_request_instances,
        1, 6,
#line 333 "./include/openvswitch/ofp-msgs.h"
        0,
#line 333 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2746 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_STATS_REQUEST,
        "OFPST_TABLE request",
    },
    {
        ofpraw_ofpst10_table_reply_instances,
        1, 1,
#line 336 "./include/openvswitch/ofp-msgs.h"
        0,
#line 336 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_table_stats),
#line 2757 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_STATS_REPLY,
        "OFPST_TABLE reply",
    },
    {
        ofpraw_ofpst11_table_reply_instances,
        2, 2,
#line 338 "./include/openvswitch/ofp-msgs.h"
        0,
#line 338 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_table_stats),
#line 2768 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_STATS_REPLY,
        "OFPST_TABLE reply",
    },
    {
        ofpraw_ofpst12_table_reply_instances,
        3, 3,
#line 340 "./include/openvswitch/ofp-msgs.h"
        0,
#line 340 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp12_table_stats),
#line 2779 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_STATS_REPLY,
        "OFPST_TABLE reply",
    },
    {
        ofpraw_ofpst13_table_reply_instances,
        4, 6,
#line 342 "./include/openvswitch/ofp-msgs.h"
        0,
#line 342 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_table_stats),
#line 2790 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_STATS_REPLY,
        "OFPST_TABLE reply",
    },
    {
        ofpraw_ofpst10_port_request_instances,
        1, 1,
#line 345 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_port_stats_request),
#line 345 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2801 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATS_REQUEST,
        "OFPST_PORT request",
    },
    {
        ofpraw_ofpst11_port_request_instances,
        2, 6,
#line 347 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_port_stats_request),
#line 347 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2812 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATS_REQUEST,
        "OFPST_PORT request",
    },
    {
        ofpraw_ofpst10_port_reply_instances,
        1, 1,
#line 350 "./include/openvswitch/ofp-msgs.h"
        0,
#line 350 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_port_stats),
#line 2823 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATS_REPLY,
        "OFPST_PORT reply",
    },
    {
        ofpraw_ofpst11_port_reply_instances,
        2, 3,
#line 352 "./include/openvswitch/ofp-msgs.h"
        0,
#line 352 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_port_stats),
#line 2834 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATS_REPLY,
        "OFPST_PORT reply",
    },
    {
        ofpraw_ofpst13_port_reply_instances,
        4, 4,
#line 354 "./include/openvswitch/ofp-msgs.h"
        0,
#line 354 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_port_stats),
#line 2845 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATS_REPLY,
        "OFPST_PORT reply",
    },
    {
        ofpraw_ofpst14_port_reply_instances,
        5, 6,
#line 356 "./include/openvswitch/ofp-msgs.h"
        0,
#line 356 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2856 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_STATS_REPLY,
        "OFPST_PORT reply",
    },
    {
        ofpraw_ofpst10_queue_request_instances,
        1, 1,
#line 359 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_queue_stats_request),
#line 359 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2867 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_STATS_REQUEST,
        "OFPST_QUEUE request",
    },
    {
        ofpraw_ofpst11_queue_request_instances,
        2, 6,
#line 361 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_queue_stats_request),
#line 361 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2878 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_STATS_REQUEST,
        "OFPST_QUEUE request",
    },
    {
        ofpraw_ofpst10_queue_reply_instances,
        1, 1,
#line 364 "./include/openvswitch/ofp-msgs.h"
        0,
#line 364 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_queue_stats),
#line 2889 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_STATS_REPLY,
        "OFPST_QUEUE reply",
    },
    {
        ofpraw_ofpst11_queue_reply_instances,
        2, 3,
#line 366 "./include/openvswitch/ofp-msgs.h"
        0,
#line 366 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_queue_stats),
#line 2900 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_STATS_REPLY,
        "OFPST_QUEUE reply",
    },
    {
        ofpraw_ofpst13_queue_reply_instances,
        4, 4,
#line 368 "./include/openvswitch/ofp-msgs.h"
        0,
#line 368 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_queue_stats),
#line 2911 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_STATS_REPLY,
        "OFPST_QUEUE reply",
    },
    {
        ofpraw_ofpst14_queue_reply_instances,
        5, 6,
#line 370 "./include/openvswitch/ofp-msgs.h"
        0,
#line 370 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2922 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_STATS_REPLY,
        "OFPST_QUEUE reply",
    },
    {
        ofpraw_nxst_group_request_instances,
        1, 1,
#line 373 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_group_stats_request),
#line 373 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2933 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_STATS_REQUEST,
        "NXST_GROUP request",
    },
    {
        ofpraw_ofpst11_group_request_instances,
        2, 6,
#line 375 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_group_stats_request),
#line 375 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2944 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_STATS_REQUEST,
        "OFPST_GROUP request",
    },
    {
        ofpraw_nxst_group_reply_instances,
        1, 1,
#line 378 "./include/openvswitch/ofp-msgs.h"
        0,
#line 378 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2955 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_STATS_REPLY,
        "NXST_GROUP reply",
    },
    {
        ofpraw_ofpst11_group_reply_instances,
        2, 3,
#line 380 "./include/openvswitch/ofp-msgs.h"
        0,
#line 380 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2966 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_STATS_REPLY,
        "OFPST_GROUP reply",
    },
    {
        ofpraw_ofpst13_group_reply_instances,
        4, 6,
#line 382 "./include/openvswitch/ofp-msgs.h"
        0,
#line 382 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 2977 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_STATS_REPLY,
        "OFPST_GROUP reply",
    },
    {
        ofpraw_nxst_group_desc_request_instances,
        1, 1,
#line 385 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp15_group_desc_request),
#line 385 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2988 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_DESC_STATS_REQUEST,
        "NXST_GROUP_DESC request",
    },
    {
        ofpraw_ofpst11_group_desc_request_instances,
        2, 5,
#line 387 "./include/openvswitch/ofp-msgs.h"
        0,
#line 387 "./include/openvswitch/ofp-msgs.h"
        0,
#line 2999 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_DESC_STATS_REQUEST,
        "OFPST_GROUP_DESC request",
    },
    {
        ofpraw_ofpst15_group_desc_request_instances,
        6, 6,
#line 389 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp15_group_desc_request),
#line 389 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3010 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_DESC_STATS_REQUEST,
        "OFPST_GROUP_DESC request",
    },
    {
        ofpraw_nxst_group_desc_reply_instances,
        1, 1,
#line 392 "./include/openvswitch/ofp-msgs.h"
        0,
#line 392 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3021 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_DESC_STATS_REPLY,
        "NXST_GROUP_DESC reply",
    },
    {
        ofpraw_ofpst11_group_desc_reply_instances,
        2, 6,
#line 394 "./include/openvswitch/ofp-msgs.h"
        0,
#line 394 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3032 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_DESC_STATS_REPLY,
        "OFPST_GROUP_DESC reply",
    },
    {
        ofpraw_nxst_group_features_request_instances,
        1, 2,
#line 397 "./include/openvswitch/ofp-msgs.h"
        0,
#line 397 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3043 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_FEATURES_STATS_REQUEST,
        "NXST_GROUP_FEATURES request",
    },
    {
        ofpraw_ofpst12_group_features_request_instances,
        3, 6,
#line 399 "./include/openvswitch/ofp-msgs.h"
        0,
#line 399 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3054 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_FEATURES_STATS_REQUEST,
        "OFPST_GROUP_FEATURES request",
    },
    {
        ofpraw_nxst_group_features_reply_instances,
        1, 2,
#line 402 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp12_group_features_stats),
#line 402 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3065 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_FEATURES_STATS_REPLY,
        "NXST_GROUP_FEATURES reply",
    },
    {
        ofpraw_ofpst12_group_features_reply_instances,
        3, 6,
#line 404 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp12_group_features_stats),
#line 404 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3076 "lib/ofp-msgs.inc"
        OFPTYPE_GROUP_FEATURES_STATS_REPLY,
        "OFPST_GROUP_FEATURES reply",
    },
    {
        ofpraw_ofpst13_meter_request_instances,
        4, 6,
#line 407 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_meter_multipart_request),
#line 407 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3087 "lib/ofp-msgs.inc"
        OFPTYPE_METER_STATS_REQUEST,
        "OFPST_METER request",
    },
    {
        ofpraw_ofpst13_meter_reply_instances,
        4, 6,
#line 410 "./include/openvswitch/ofp-msgs.h"
        0,
#line 410 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3098 "lib/ofp-msgs.inc"
        OFPTYPE_METER_STATS_REPLY,
        "OFPST_METER reply",
    },
    {
        ofpraw_ofpst13_meter_config_request_instances,
        4, 6,
#line 413 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_meter_multipart_request),
#line 413 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3109 "lib/ofp-msgs.inc"
        OFPTYPE_METER_CONFIG_STATS_REQUEST,
        "OFPST_METER_CONFIG request",
    },
    {
        ofpraw_ofpst13_meter_config_reply_instances,
        4, 6,
#line 416 "./include/openvswitch/ofp-msgs.h"
        0,
#line 416 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3120 "lib/ofp-msgs.inc"
        OFPTYPE_METER_CONFIG_STATS_REPLY,
        "OFPST_METER_CONFIG reply",
    },
    {
        ofpraw_ofpst13_meter_features_request_instances,
        4, 6,
#line 419 "./include/openvswitch/ofp-msgs.h"
        0,
#line 419 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3131 "lib/ofp-msgs.inc"
        OFPTYPE_METER_FEATURES_STATS_REQUEST,
        "OFPST_METER_FEATURES request",
    },
    {
        ofpraw_ofpst13_meter_features_reply_instances,
        4, 6,
#line 422 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_meter_features),
#line 422 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3142 "lib/ofp-msgs.inc"
        OFPTYPE_METER_FEATURES_STATS_REPLY,
        "OFPST_METER_FEATURES reply",
    },
    {
        ofpraw_ofpst13_table_features_request_instances,
        4, 6,
#line 425 "./include/openvswitch/ofp-msgs.h"
        0,
#line 425 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3153 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_FEATURES_STATS_REQUEST,
        "OFPST_TABLE_FEATURES request",
    },
    {
        ofpraw_ofpst13_table_features_reply_instances,
        4, 6,
#line 428 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp13_table_features),
#line 428 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3164 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_FEATURES_STATS_REPLY,
        "OFPST_TABLE_FEATURES reply",
    },
    {
        ofpraw_ofpst14_table_desc_request_instances,
        5, 6,
#line 431 "./include/openvswitch/ofp-msgs.h"
        0,
#line 431 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3175 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_DESC_REQUEST,
        "OFPST_TABLE_DESC request",
    },
    {
        ofpraw_ofpst14_table_desc_reply_instances,
        5, 6,
#line 434 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_table_desc),
#line 434 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3186 "lib/ofp-msgs.inc"
        OFPTYPE_TABLE_DESC_REPLY,
        "OFPST_TABLE_DESC reply",
    },
    {
        ofpraw_ofpst10_port_desc_request_instances,
        1, 5,
#line 437 "./include/openvswitch/ofp-msgs.h"
        0,
#line 437 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3197 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_DESC_STATS_REQUEST,
        "OFPST_PORT_DESC request",
    },
    {
        ofpraw_ofpst15_port_desc_request_instances,
        6, 6,
#line 439 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp15_port_desc_request),
#line 439 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3208 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_DESC_STATS_REQUEST,
        "OFPST_PORT_DESC request",
    },
    {
        ofpraw_ofpst10_port_desc_reply_instances,
        1, 1,
#line 442 "./include/openvswitch/ofp-msgs.h"
        0,
#line 442 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp10_phy_port),
#line 3219 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_DESC_STATS_REPLY,
        "OFPST_PORT_DESC reply",
    },
    {
        ofpraw_ofpst11_port_desc_reply_instances,
        2, 4,
#line 444 "./include/openvswitch/ofp-msgs.h"
        0,
#line 444 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp11_port),
#line 3230 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_DESC_STATS_REPLY,
        "OFPST_PORT_DESC reply",
    },
    {
        ofpraw_ofpst14_port_desc_reply_instances,
        5, 6,
#line 446 "./include/openvswitch/ofp-msgs.h"
        0,
#line 446 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3241 "lib/ofp-msgs.inc"
        OFPTYPE_PORT_DESC_STATS_REPLY,
        "OFPST_PORT_DESC reply",
    },
    {
        ofpraw_ofpst14_queue_desc_request_instances,
        5, 6,
#line 449 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct ofp14_queue_desc_request),
#line 449 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3252 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_GET_CONFIG_REQUEST,
        "OFPST_QUEUE_DESC request",
    },
    {
        ofpraw_ofpst14_queue_desc_reply_instances,
        5, 6,
#line 451 "./include/openvswitch/ofp-msgs.h"
        0,
#line 451 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3263 "lib/ofp-msgs.inc"
        OFPTYPE_QUEUE_GET_CONFIG_REPLY,
        "OFPST_QUEUE_DESC reply",
    },
    {
        ofpraw_ofpst14_flow_monitor_request_instances,
        5, 6,
#line 454 "./include/openvswitch/ofp-msgs.h"
        0,
#line 454 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3274 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_STATS_REQUEST,
        "OFPST_FLOW_MONITOR request",
    },
    {
        ofpraw_onfst13_flow_monitor_request_instances,
        4, 4,
#line 456 "./include/openvswitch/ofp-msgs.h"
        0,
#line 456 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3285 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_STATS_REQUEST,
        "ONFST_FLOW_MONITOR request",
    },
    {
        ofpraw_nxst_flow_monitor_request_instances,
        1, 3,
#line 458 "./include/openvswitch/ofp-msgs.h"
        0,
#line 458 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3296 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_STATS_REQUEST,
        "NXST_FLOW_MONITOR request",
    },
    {
        ofpraw_ofpst14_flow_monitor_reply_instances,
        5, 6,
#line 461 "./include/openvswitch/ofp-msgs.h"
        0,
#line 461 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3307 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_STATS_REPLY,
        "OFPST_FLOW_MONITOR reply",
    },
    {
        ofpraw_onfst13_flow_monitor_reply_instances,
        4, 4,
#line 463 "./include/openvswitch/ofp-msgs.h"
        0,
#line 463 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3318 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_STATS_REPLY,
        "ONFST_FLOW_MONITOR reply",
    },
    {
        ofpraw_nxst_flow_monitor_reply_instances,
        1, 3,
#line 465 "./include/openvswitch/ofp-msgs.h"
        0,
#line 465 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3329 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_STATS_REPLY,
        "NXST_FLOW_MONITOR reply",
    },
    {
        ofpraw_onft13_flow_monitor_cancel_instances,
        4, 4,
#line 468 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_flow_monitor_cancel),
#line 468 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3340 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_CANCEL,
        "ONFT_FLOW_MONITOR_CANCEL",
    },
    {
        ofpraw_nxt_flow_monitor_cancel_instances,
        1, 3,
#line 470 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_flow_monitor_cancel),
#line 470 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3351 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_CANCEL,
        "NXT_FLOW_MONITOR_CANCEL",
    },
    {
        ofpraw_onft13_flow_monitor_paused_instances,
        4, 4,
#line 473 "./include/openvswitch/ofp-msgs.h"
        0,
#line 473 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3362 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_PAUSED,
        "ONFT_FLOW_MONITOR_PAUSED",
    },
    {
        ofpraw_nxt_flow_monitor_paused_instances,
        1, 3,
#line 475 "./include/openvswitch/ofp-msgs.h"
        0,
#line 475 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3373 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_PAUSED,
        "NXT_FLOW_MONITOR_PAUSED",
    },
    {
        ofpraw_onft13_flow_monitor_resumed_instances,
        4, 4,
#line 478 "./include/openvswitch/ofp-msgs.h"
        0,
#line 478 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3384 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_RESUMED,
        "ONFT_FLOW_MONITOR_RESUMED",
    },
    {
        ofpraw_nxt_flow_monitor_resumed_instances,
        1, 3,
#line 480 "./include/openvswitch/ofp-msgs.h"
        0,
#line 480 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3395 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MONITOR_RESUMED,
        "NXT_FLOW_MONITOR_RESUMED",
    },
    {
        ofpraw_nxt_set_flow_format_instances,
        1, 1,
#line 488 "./include/openvswitch/ofp-msgs.h"
        sizeof(ovs_be32),
#line 488 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3406 "lib/ofp-msgs.inc"
        OFPTYPE_SET_FLOW_FORMAT,
        "NXT_SET_FLOW_FORMAT",
    },
    {
        ofpraw_nxt_flow_mod_table_id_instances,
        1, 6,
#line 491 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 491 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3417 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_MOD_TABLE_ID,
        "NXT_FLOW_MOD_TABLE_ID",
    },
    {
        ofpraw_nxt_set_packet_in_format_instances,
        1, 6,
#line 494 "./include/openvswitch/ofp-msgs.h"
        sizeof(ovs_be32),
#line 494 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3428 "lib/ofp-msgs.inc"
        OFPTYPE_SET_PACKET_IN_FORMAT,
        "NXT_SET_PACKET_IN_FORMAT",
    },
    {
        ofpraw_nxt_flow_age_instances,
        1, 6,
#line 497 "./include/openvswitch/ofp-msgs.h"
        0,
#line 497 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3439 "lib/ofp-msgs.inc"
        OFPTYPE_FLOW_AGE,
        "NXT_FLOW_AGE",
    },
    {
        ofpraw_nxt_set_controller_id_instances,
        1, 6,
#line 500 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_controller_id),
#line 500 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3450 "lib/ofp-msgs.inc"
        OFPTYPE_SET_CONTROLLER_ID,
        "NXT_SET_CONTROLLER_ID",
    },
    {
        ofpraw_nxt_tlv_table_mod_instances,
        1, 6,
#line 503 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_tlv_table_mod),
#line 503 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_tlv_map),
#line 3461 "lib/ofp-msgs.inc"
        OFPTYPE_NXT_TLV_TABLE_MOD,
        "NXT_TLV_TABLE_MOD",
    },
    {
        ofpraw_nxt_tlv_table_request_instances,
        1, 6,
#line 506 "./include/openvswitch/ofp-msgs.h"
        0,
#line 506 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3472 "lib/ofp-msgs.inc"
        OFPTYPE_NXT_TLV_TABLE_REQUEST,
        "NXT_TLV_TABLE_REQUEST",
    },
    {
        ofpraw_nxt_tlv_table_reply_instances,
        1, 6,
#line 509 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_tlv_table_reply),
#line 509 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_tlv_map),
#line 3483 "lib/ofp-msgs.inc"
        OFPTYPE_NXT_TLV_TABLE_REPLY,
        "NXT_TLV_TABLE_REPLY",
    },
    {
        ofpraw_nxt_resume_instances,
        1, 6,
#line 512 "./include/openvswitch/ofp-msgs.h"
        0,
#line 512 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3494 "lib/ofp-msgs.inc"
        OFPTYPE_NXT_RESUME,
        "NXT_RESUME",
    },
    {
        ofpraw_nxt_ct_flush_zone_instances,
        1, 6,
#line 515 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_zone_id),
#line 515 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3505 "lib/ofp-msgs.inc"
        OFPTYPE_CT_FLUSH_ZONE,
        "NXT_CT_FLUSH_ZONE",
    },
    {
        ofpraw_nxt_ct_flush_instances,
        1, 6,
#line 518 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_ct_flush),
#line 518 "./include/openvswitch/ofp-msgs.h"
        sizeof(uint8_t[8]),
#line 3516 "lib/ofp-msgs.inc"
        OFPTYPE_CT_FLUSH,
        "NXT_CT_FLUSH",
    },
    {
        ofpraw_nxst_ipfix_bridge_request_instances,
        1, 6,
#line 521 "./include/openvswitch/ofp-msgs.h"
        0,
#line 521 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3527 "lib/ofp-msgs.inc"
        OFPTYPE_IPFIX_BRIDGE_STATS_REQUEST,
        "NXST_IPFIX_BRIDGE request",
    },
    {
        ofpraw_nxst_ipfix_bridge_reply_instances,
        1, 6,
#line 524 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_ipfix_stats_reply),
#line 524 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3538 "lib/ofp-msgs.inc"
        OFPTYPE_IPFIX_BRIDGE_STATS_REPLY,
        "NXST_IPFIX_BRIDGE reply",
    },
    {
        ofpraw_nxst_ipfix_flow_request_instances,
        1, 6,
#line 527 "./include/openvswitch/ofp-msgs.h"
        0,
#line 527 "./include/openvswitch/ofp-msgs.h"
        0,
#line 3549 "lib/ofp-msgs.inc"
        OFPTYPE_IPFIX_FLOW_STATS_REQUEST,
        "NXST_IPFIX_FLOW request",
    },
    {
        ofpraw_nxst_ipfix_flow_reply_instances,
        1, 6,
#line 530 "./include/openvswitch/ofp-msgs.h"
        0,
#line 530 "./include/openvswitch/ofp-msgs.h"
        sizeof(struct nx_ipfix_stats_reply),
#line 3560 "lib/ofp-msgs.inc"
        OFPTYPE_IPFIX_FLOW_STATS_REPLY,
        "NXST_IPFIX_FLOW reply",
    },
};

static const char *type_names[] = {
    "OFPT_HELLO",
    "OFPT_ERROR",
    "OFPT_ECHO_REQUEST",
    "OFPT_ECHO_REPLY",
    "OFPT_FEATURES_REQUEST",
    "OFPT_FEATURES_REPLY",
    "OFPT_GET_CONFIG_REQUEST",
    "OFPT_GET_CONFIG_REPLY",
    "OFPT_SET_CONFIG",
    "OFPT_PACKET_IN",
    "OFPT_FLOW_REMOVED",
    "OFPT_PORT_STATUS",
    "OFPT_PACKET_OUT",
    "OFPT_FLOW_MOD",
    "NXT_GROUP_MOD",
    "OFPT_PORT_MOD",
    "OFPT_TABLE_MOD",
    "OFPT_BARRIER_REQUEST",
    "OFPT_BARRIER_REPLY",
    "OFPT_QUEUE_GET_CONFIG_REQUEST",
    "OFPT_QUEUE_GET_CONFIG_REPLY",
    "OFPT_ROLE_REQUEST",
    "OFPT_ROLE_REPLY",
    "OFPT_GET_ASYNC_REQUEST",
    "OFPT_GET_ASYNC_REPLY",
    "NXT_SET_ASYNC_CONFIG",
    "OFPT_METER_MOD",
    "ONFT_ROLE_STATUS",
    "NXT_REQUESTFORWARD",
    "OFPT_TABLE_STATUS",
    "OFPT_BUNDLE_CONTROL",
    "OFPT_BUNDLE_ADD_MESSAGE",
    "OFPST_DESC request",
    "OFPST_DESC reply",
    "OFPST_FLOW request",
    "OFPST_FLOW reply",
    "OFPST_AGGREGATE request",
    "OFPST_AGGREGATE reply",
    "OFPST_TABLE request",
    "OFPST_TABLE reply",
    "OFPST_PORT request",
    "OFPST_PORT reply",
    "OFPST_QUEUE request",
    "OFPST_QUEUE reply",
    "NXST_GROUP request",
    "NXST_GROUP reply",
    "NXST_GROUP_DESC request",
    "NXST_GROUP_DESC reply",
    "NXST_GROUP_FEATURES request",
    "NXST_GROUP_FEATURES reply",
    "OFPST_METER request",
    "OFPST_METER reply",
    "OFPST_METER_CONFIG request",
    "OFPST_METER_CONFIG reply",
    "OFPST_METER_FEATURES request",
    "OFPST_METER_FEATURES reply",
    "OFPST_TABLE_FEATURES request",
    "OFPST_TABLE_FEATURES reply",
    "OFPST_TABLE_DESC request",
    "OFPST_TABLE_DESC reply",
    "OFPST_PORT_DESC request",
    "OFPST_PORT_DESC reply",
    "OFPST_FLOW_MONITOR request",
    "OFPST_FLOW_MONITOR reply",
    "NXT_SET_FLOW_FORMAT",
    "NXT_FLOW_MOD_TABLE_ID",
    "NXT_SET_PACKET_IN_FORMAT",
    "NXT_FLOW_AGE",
    "NXT_SET_CONTROLLER_ID",
    "NXT_TLV_TABLE_MOD",
    "NXT_TLV_TABLE_REQUEST",
    "NXT_TLV_TABLE_REPLY",
    "NXT_RESUME",
    "NXST_IPFIX_BRIDGE request",
    "NXST_IPFIX_BRIDGE reply",
    "NXST_IPFIX_FLOW request",
    "NXST_IPFIX_FLOW reply",
    "NXT_CT_FLUSH_ZONE",
    "NXT_CT_FLUSH",
    "NXT_FLOW_MONITOR_CANCEL",
    "NXT_FLOW_MONITOR_PAUSED",
    "NXT_FLOW_MONITOR_RESUMED",
};
